package com.clcbio.api.clc.workflows.bean;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;

/**
 * Bean representation of a com.clcbio.api.clc.workflows.Workflow for serialization
 * 
 * @author joecker
 * 
 */
public class WorkflowBean implements Serializable {
    private static final long serialVersionUID = 8944074369062810397L;
    private Collection<WorkflowConnectionBean> workflowConnections;
    private Collection<WorkflowElementBean> workflowElements;
    private String description;
    private String name;
    private String classKey;
    private String id;
    private double version;
    private long apiVersion;
    
    public WorkflowBean() {
        workflowConnections = new ArrayList<WorkflowConnectionBean>();
        workflowElements = new ArrayList<WorkflowElementBean>();
        description = "";
        name = "";
        classKey = "";
        id = "";
        apiVersion = 0;
    }
    
    public WorkflowBean(WorkflowBean cloneSource) {
        this.description = cloneSource.getDescription();
        this.name = cloneSource.getName();
        this.classKey = cloneSource.getClassKey();
        this.description = cloneSource.getDescription();
        workflowConnections = new ArrayList<WorkflowConnectionBean>();
        for (WorkflowConnectionBean source : cloneSource.getWorkflowConnections()) {
            workflowConnections.add(new WorkflowConnectionBean(source));
        }
        workflowElements = new ArrayList<WorkflowElementBean>();
        for (WorkflowElementBean source : cloneSource.getWorkflowElements()) {
            workflowElements.add(new WorkflowElementBean(source));
        }
        this.version = cloneSource.version;
        this.apiVersion = cloneSource.apiVersion;
    }
    
    public long getApiVersion() {
        return apiVersion;
    }
    
    public void setApiVersion(long apiVersion) {
        this.apiVersion = apiVersion;
    }

    public double getVersion() {
        return version;
    }
    
    public void setVersion(double version) {
        this.version = version;
    }
    
    public String getId() {
        return id;
    }
    
    public void setId(String id) {
        this.id = id;
    }
    
    public String getClassKey() {
        return classKey;
    }
    
    public void setDescription(String description) {
        this.description = description;
    }
    
    public void setName(String name) {
        this.name = name;
    }
    
    public void setClassKey(String classKey) {
        this.classKey = classKey;
    }
    
    public String getName() {
        return name;
    }
    
    public String getDescription() {
        return description;
    }
    
    public void setWorkflowElements(Collection<WorkflowElementBean> beans) {
        this.workflowElements = beans;
    }
    
    public Collection<WorkflowElementBean> getWorkflowElements() {
        return workflowElements;
    }
    
    public void setWorkflowConnections(Collection<WorkflowConnectionBean> beans) {
        this.workflowConnections = beans;
    }
    
    public Collection<WorkflowConnectionBean> getWorkflowConnections() {
        return workflowConnections;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        WorkflowBean other = (WorkflowBean) obj;
        if (classKey == null) {
            if (other.classKey != null)
                return false;
        }
        else if (!classKey.equals(other.classKey))
            return false;
        if (description == null) {
            if (other.description != null)
                return false;
        }
        else if (!description.equals(other.description))
            return false;
        if (id == null) {
            if (other.id != null)
                return false;
        }
        else if (!id.equals(other.id))
            return false;
        if (name == null) {
            if (other.name != null)
                return false;
        }
        else if (!name.equals(other.name))
            return false;
        if (!Double.valueOf(version).equals(Double.valueOf(other.version)))
            return false;
        if (workflowConnections == null) {
            if (other.workflowConnections != null)
                return false;
        }
        else if (!workflowConnections.equals(other.workflowConnections))
            return false;
        if (workflowElements == null) {
            if (other.workflowElements != null)
                return false;
        }
        else if (!workflowElements.equals(other.workflowElements))
            return false;
        return true;
    }
    
    @Override
    public String toString() {
        return "WorkflowBean [workflowConnections=" + workflowConnections + ", workflowElements=" + workflowElements
                + ", description=" + description + ", name=" + name + ", classKey=" + classKey + ", id=" + id + ", version=" + version
                + "]";
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((classKey == null) ? 0 : classKey.hashCode());
        result = prime * result + ((description == null) ? 0 : description.hashCode());
        result = prime * result + ((id == null) ? 0 : id.hashCode());
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        result = prime * result + Double.valueOf(version).hashCode();
        result = prime * result + ((workflowConnections == null) ? 0 : workflowConnections.hashCode());
        result = prime * result + ((workflowElements == null) ? 0 : workflowElements.hashCode());
        return result;
    }
}
