package com.clcbio.api.clc.workflows.bean;

import java.io.Serializable;

/**
 * Bean representation of com.clcbio.api.clc.workflows.Workflow for serialization
 * 
 * @author joecker
 * 
 */
public class WorkflowConnectionBean implements Serializable {
    private static final long serialVersionUID = -8948797687964098170L;
    private WorkflowElementBean source;
    private WorkflowElementBean target;
    private WorkflowHandlerBean outputChannelReference;
    private WorkflowHandlerBean inputChannelReference;
    private boolean workflowOutput;
    private boolean workflowInput;
    
    public WorkflowConnectionBean() {
        source = new WorkflowElementBean();
        target = new WorkflowElementBean();
        outputChannelReference = new WorkflowHandlerBean();
        inputChannelReference = new WorkflowHandlerBean();
        workflowOutput = true;
        workflowInput = true;
    }
    
    public WorkflowConnectionBean(WorkflowConnectionBean cloneSource) {
        source = new WorkflowElementBean(cloneSource.getSource());
        target = new WorkflowElementBean(cloneSource.getTarget());
        outputChannelReference = new WorkflowHandlerBean(cloneSource.getOutputChannelReference());
        inputChannelReference = new WorkflowHandlerBean(cloneSource.getInputChannelReference());
        workflowOutput = cloneSource.isWorkflowOutput();
        workflowInput = cloneSource.isWorkflowInput();
    }
    
    public boolean isWorkflowOutput() {
        return workflowOutput;
    }
    
    public WorkflowHandlerBean getInputChannelReference() {
        return inputChannelReference;
    }
    
    public void setOutputChannelReference(WorkflowHandlerBean outputHandler) {
        this.outputChannelReference = outputHandler;
    }
    
    public void setInputChannelReference(WorkflowHandlerBean inputHandler) {
        this.inputChannelReference = inputHandler;
    }
    
    public WorkflowHandlerBean getOutputChannelReference() {
        return outputChannelReference;
    }
    
    public void setWorkflowOutput(boolean workflowOutput) {
        this.workflowOutput = workflowOutput;
    }
    
    public boolean isWorkflowInput() {
        return workflowInput;
    }
    
    public void setWorkflowInput(boolean workflowInput) {
        this.workflowInput = workflowInput;
    }
    
    public void setSource(WorkflowElementBean source) {
        this.source = source;
    }
    
    public WorkflowElementBean getSource() {
        return source;
    }
    
    public void setTarget(WorkflowElementBean target) {
        this.target = target;
    }
    
    public WorkflowElementBean getTarget() {
        return target;
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((inputChannelReference == null) ? 0 : inputChannelReference.hashCode());
        result = prime * result + ((outputChannelReference == null) ? 0 : outputChannelReference.hashCode());
        result = prime * result + ((source == null) ? 0 : source.hashCode());
        result = prime * result + ((target == null) ? 0 : target.hashCode());
        result = prime * result + (workflowInput ? 1231 : 1237);
        result = prime * result + (workflowOutput ? 1231 : 1237);
        return result;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        WorkflowConnectionBean other = (WorkflowConnectionBean) obj;
        if (inputChannelReference == null) {
            if (other.inputChannelReference != null)
                return false;
        }
        else if (!inputChannelReference.equals(other.inputChannelReference))
            return false;
        if (outputChannelReference == null) {
            if (other.outputChannelReference != null)
                return false;
        }
        else if (!outputChannelReference.equals(other.outputChannelReference))
            return false;
        if (source == null) {
            if (other.source != null)
                return false;
        }
        else if (!source.equals(other.source))
            return false;
        if (target == null) {
            if (other.target != null)
                return false;
        }
        else if (!target.equals(other.target))
            return false;
        if (workflowInput != other.workflowInput)
            return false;
        if (workflowOutput != other.workflowOutput)
            return false;
        return true;
    }
    
    @Override
    public String toString() {
        return "WorkflowConnectionBean [source=" + source + ", target=" + target + ", outputChannelReference="
                + outputChannelReference + ", inputChannelReference=" + inputChannelReference + ", workflowOutput=" + workflowOutput
                + ", workflowInput=" + workflowInput + "]";
    }
    
}
