package com.clcbio.api.clc.workflows.bean;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

/**
 * Bean representation of a com.clcbio.api.clc.workflows.Workflow for serialization.
 * 
 * @author joecker
 * 
 */
public class WorkflowElementBean implements Serializable {
    private static final long serialVersionUID = 425180139802865294L;
    private WorkflowElementBeanParameter parameters;
    private String classKey;
    private String description;
    private String name;
    private String id;
    private String commandId;
    private String serverCommandName;
    private double version;
    private boolean input;
    private boolean output;
    private Map<String, WorkflowRole> parameterByRole;
    
    public WorkflowElementBean() {
        description = "";
        name = "";
        id = "";
        parameterByRole = new HashMap<String, WorkflowRole>();
    }
    
    public WorkflowElementBean(WorkflowElementBean cloneSource) {
        description = cloneSource.getDescription();
        name = cloneSource.getName();
        commandId = cloneSource.getCommandId();
        input = cloneSource.isInput();
        output = cloneSource.isOutput();
        serverCommandName = cloneSource.getServerCommandName();
        version = cloneSource.getVersion();
        parameterByRole = cloneSource.getParameterByRole();
    }
    
    public Map<String, WorkflowRole> getParameterByRole() {
        return parameterByRole;
    }
    
    public void setParameterByRole(Map<String, WorkflowRole> parameterRoles) {
        this.parameterByRole = parameterRoles;
    }
    
    public boolean isInternal() {
        return !isInput() && !isOutput();
    }
    
    public boolean isInput() {
        return input;
    }
    
    public void setInput(boolean input) {
        this.input = input;
    }
    
    public boolean isOutput() {
        return output;
    }
    
    public void setOutput(boolean output) {
        this.output = output;
    }
    
    public void setVersion(double version) {
        this.version = version;
    }
    
    public double getVersion() {
        return version;
    }
    
    public String getCommandId() {
        return commandId;
    }
    
    public void setCommandId(String commandId) {
        this.commandId = commandId;
    }
    
    public String getName() {
        return name;
    }
    
    public String getId() {
        return id;
    }
    
    public void setId(String id) {
        this.id = id;
    }
    
    public void setClassKey(String classKey) {
        this.classKey = classKey;
    }
    
    public void setDescription(String description) {
        this.description = description;
    }
    
    public void setName(String name) {
        this.name = name;
    }
    
    public String getDescription() {
        return description;
    }
    
    public String getClassKey() {
        return classKey;
    }
    
    public WorkflowElementBeanParameter getParameters() {
        return parameters;
    }
    
    public void setParameters(WorkflowElementBeanParameter parameters_new) {
        this.parameters = parameters_new;
    }
    
    public String getServerCommandName() {
        return serverCommandName;
    }
    
    public void setServerCommandName(String serverCommandName) {
        this.serverCommandName = serverCommandName;
    }
    
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((classKey == null) ? 0 : classKey.hashCode());
        result = prime * result + ((commandId == null) ? 0 : commandId.hashCode());
        result = prime * result + ((description == null) ? 0 : description.hashCode());
        result = prime * result + ((id == null) ? 0 : id.hashCode());
        result = prime * result + (input ? 1231 : 1237);
        result = prime * result + ((parameterByRole == null) ? 0 : parameterByRole.hashCode());
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        result = prime * result + (output ? 1231 : 1237);
        result = prime * result + ((parameters == null) ? 0 : parameters.hashCode());
        result = prime * result + ((serverCommandName == null) ? 0 : serverCommandName.hashCode());
        result = prime * result + Double.valueOf(version).hashCode();
        return result;
    }
    
    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        WorkflowElementBean other = (WorkflowElementBean) obj;
        if (classKey == null) {
            if (other.classKey != null)
                return false;
        }
        else if (!classKey.equals(other.classKey))
            return false;
        if (commandId == null) {
            if (other.commandId != null)
                return false;
        }
        else if (!commandId.equals(other.commandId))
            return false;
        if (description == null) {
            if (other.description != null)
                return false;
        }
        else if (!description.equals(other.description))
            return false;
        if (id == null) {
            if (other.id != null)
                return false;
        }
        else if (!id.equals(other.id))
            return false;
        if (input != other.input)
            return false;
        if (parameterByRole == null) {
            if (other.parameterByRole != null)
                return false;
        }
        else if (!parameterByRole.equals(other.parameterByRole))
            return false;
        if (name == null) {
            if (other.name != null)
                return false;
        }
        else if (!name.equals(other.name))
            return false;
        if (output != other.output)
            return false;
        if (parameters == null) {
            if (other.parameters != null)
                return false;
        }
        else if (!parameters.equals(other.parameters))
            return false;
        if (serverCommandName == null) {
            if (other.serverCommandName != null)
                return false;
        }
        else if (!serverCommandName.equals(other.serverCommandName))
            return false;
        if (!Double.valueOf(version).equals(Double.valueOf(other.version)))
            return false;
        return true;
    }
    
    @Override
    public String toString() {
        return "WorkflowElementBean [parameters=" + parameters + ", classKey=" + classKey + ", description=" + description + ", name="
                + name + ", id=" + id + ", commandId=" + commandId + ", serverCommandName=" + serverCommandName + ", version="
                + version + ", input=" + input + ", output=" + output + ", parameterByRole=" + parameterByRole + "]";
    }
}
