package com.clcbio.api.clc.workflows.bean;

import java.io.Serializable;

/**
 * A {@link WorkflowRole} represents the different stages the workflow passes (creation, installation, execution).
 * 
 * The stages are organized hierarchically, so that there is a specific order amongst the stages, whereas {@link #CREATOR} is the top,
 * followed by {@link #ADMINISTRATOR} and {@link #ENDUSER}
 * 
 * @author joecker
 * 
 */
public enum WorkflowRole implements Serializable {
    CREATOR {
        @Override
        public boolean overrule(WorkflowRole stage) {
            return true;
        }
    }
    ,
    ADMINISTRATOR {
        @Override
        public boolean overrule(WorkflowRole role) {
            return role != CREATOR;
        }
    },
    ENDUSER {
        @Override
        public boolean overrule(WorkflowRole role) {
            return role == ENDUSER || role == NONE;
        }
    },
    NONE {
        @Override
        public boolean overrule(WorkflowRole role) {
            return false;
        }
    };
    
    /**
     * Returns true whether this stage can overrule the given stage
     * 
     * @param role
     * @return
     */
    public abstract boolean overrule(WorkflowRole role);
}
