package com.clcbio.client.thin.api;

import java.util.List;

import com.clcbio.client.thin.model.CLCClientSession;
import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.ThinBinaryData;
import com.clcbio.client.thin.model.admin.ThinPluginDescriptor;
import com.clcbio.client.thin.model.admin.configuration.ServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.ServerConfigurationModule;
import com.clcbio.client.thin.model.bugsubmission.DiagnosticsCheckType;
import com.clcbio.client.thin.model.bugsubmission.DiagnosticsReport;
import com.clcbio.client.thin.model.bugsubmission.SystemInformationQuery;
import com.clcbio.client.thin.model.exceptions.ServiceException;
import com.clcbio.client.thin.model.log.LogQuery;
import com.clcbio.client.thin.model.processes.ClcProcessReflection;
import com.clcbio.client.thin.model.processes.ServerProcessManagerProcesses;
import com.clcbio.client.thin.model.safefile.SafeFileLocation;
import com.clcbio.client.thin.model.safefile.SafeFileLocations;
import com.google.gwt.user.client.rpc.AsyncCallback;

public interface CLCServerApiAdminAsync extends SerializableGWTTypesAsync {
    public void login(String username, String password, AsyncCallback callback);

    public void logout(CLCClientSession clientSession, AsyncCallback callback);

    public void heartBeat(String sessionID, AsyncCallback callback);

    public void getServerStatus(String sessionID, AsyncCallback callback);

    public void setServerConfiguration(String sessionID, ServerConfiguration serverConfiguration,
            AsyncCallback<ServerConfiguration> callback);

    public void getServerConfiguration(String sessionID, ServerConfigurationModule configurationModule,
            AsyncCallback<ServerConfiguration> callback);

    public void getProcessManagerProcesses(String sessionID, AsyncCallback<ServerProcessManagerProcesses> callback);

    public void processManagerMoveProcessForward(String sessionID, ClcProcessReflection queuedCommand, AsyncCallback callback);

    public void processManagerMoveProcessBackward(String sessionID, ClcProcessReflection queuedCommand, AsyncCallback callback);

    public void auditLogQuery(String sessionID, LogQuery logQuery, AsyncCallback callback);

    public void getInstalledPlugins(String sessionID, AsyncCallback<List<ThinPluginDescriptor>> callback);

    public void removeUser(String userId, String sessionID, AsyncCallback callback);

    public void addUser(String userId, String password, String sessionID, AsyncCallback callback);

    public void setPassword(String userId, String password, String sessionID, AsyncCallback callback);

    public void addUserToGroup(String userId, String groupId, String sessionID, AsyncCallback callback);

    public void removeUserFromGroup(String userId, String groupId, String sessionID, AsyncCallback callback);

    public void removeGroup(String groupId, String sessionID, AsyncCallback callback);

    public void addGroup(String groupId, String sessionID, AsyncCallback callback);

    public void canEditUsersAndGroups(String sessionID, AsyncCallback callback);

    public void getAdminGroupID(String sessionID, AsyncCallback callback);

    public void isAdmin(String sessionID, AsyncCallback callback);

    public void setRootPassword(String currentPassword, String newPassword, String sessionID, AsyncCallback callback);

    public void invalidateUserHttpSession(String adminSessionID, String userSessionId, String invalidationReason,
            AsyncCallback callback);

    public void listSafeFilesIn(String sessionID, SafeFileLocation safeFilesLocation, AsyncCallback<SafeFileLocations> callback);

    public void generateSystemInformationArchive(String sessionID, SystemInformationQuery systemInformationQuery,
            AsyncCallback callback);

    public void getIndexServerStatus(String sessionID, AsyncCallback callback);

    public void generateSystemDiagnosticsReport(String sessionID, DiagnosticsCheckType checkType,
            AsyncCallback<List<DiagnosticsReport>> callback);
    
    public void javaBeanXMLDecode(String sessionID, String serialisedXmlBean, AsyncCallback<CommonBeanSerialization> callback);

    public void getPlugins(String sessionID, List<ThinPluginDescriptor> pluginList, AsyncCallback<List<ThinBinaryData>> callback);
}
