package com.clcbio.client.thin.api;

import java.util.List;

import com.clcbio.client.thin.model.ThinBinaryData;
import com.clcbio.client.thin.model.exceptions.ServiceException;
import com.clcbio.client.thin.model.persistence.TransportInsertResult;
import com.clcbio.client.thin.model.persistence.TransportPersistenceContainer;
import com.clcbio.client.thin.model.persistence.TransportPersistenceElement;
import com.clcbio.client.thin.model.persistence.TransportPersistenceStructure;
import com.clcbio.client.thin.model.persistence.TransportPersistenceStructureScore;
import com.clcbio.client.thin.model.persistence.TransportRecycleBin;

public interface CLCServerApiPersistenceModel extends SerializableGWTTypes {
    public void addLazyObject(String pmId, byte[] lazyObject, String main_id, int obj_id, String sessionId) throws ServiceException;
    
    public int allocateObjectId(String pmId, String containerId, String elementId, String sessionId) throws ServiceException;
    
    public void commitInsert(String pmId, String containerId, String id, byte[] document, int elementCount, String sessionId)
            throws ServiceException;
    
    public void commitUpdate(String pmId, String containerId, String id, byte[] document, int elementCount, String sessionId)
            throws ServiceException;
    
    public TransportPersistenceContainer createContainer(String pmId, String containerId, String containerName, String refId,
            String sessionId) throws ServiceException;
    
    public boolean exists(String pmId, String elementId, String sessionId) throws ServiceException;
    
    public ThinBinaryData export(String pmId, String containerId, String structureId, String sessionId) throws ServiceException;
    
    public List<TransportPersistenceStructure> fetch(String pmId, String structureId, String sessionId) throws ServiceException;
    
    public byte[] fetchLazyByteArray(String pmId, String main_id, int obj_id, String sessionId) throws ServiceException;
    
    public byte[] getAttribute(String pmId, String attributeId, String sessionId) throws ServiceException;
    
    public byte[] getAllAttributes(String pmId, String sessionId) throws ServiceException;
    
    public TransportRecycleBin getRecycleBin(String pmId, String sessionId) throws ServiceException;
    
    public void insertAttribute(String pmId, byte[] attribute, String sessionId) throws ServiceException;
    
    public TransportPersistenceStructure insertCopyBefore(String pmId, String containerId, String origPmId, boolean isInRecycleBin,
            String structureId, String refId, String sessionId) throws ServiceException;
    
    public TransportPersistenceElement insertFileObjectBefore(String pmId, String containerId, ThinBinaryData file, String refId,
            String sessionId) throws ServiceException;
    
    public List<TransportPersistenceStructure> list(String pmId, String containerId, boolean inRecycleBin, String sessionId)
            throws ServiceException;
    
    public List<TransportPersistenceContainer> listPersistenceModels(String sessionId) throws ServiceException;
    
    public String moveBefore(String pmId, String parentContainerId, String containerId, String structureId, String refId,
            boolean sourceIsRecycleBin, String sessionId) throws ServiceException;
    
    public boolean permissionsSupport(String pmId, String sessionId) throws ServiceException;
    
    public void removeAttribute(String pmId, byte[] attribute, String sessionId) throws ServiceException;
    
    public void removeFromRecycleBin(String pmId, String structureId, String sessionId) throws ServiceException;
    
    public String renameChild(String pmId, String containerId, String elementId, String sessionId, String newName)
            throws ServiceException;
    
    public List<TransportPersistenceStructureScore> searchWithScore(String pmId, String query, int start, int max, String sessionId)
            throws ServiceException;
    
    public void sort(String pmId, String containerId, String sessionId) throws ServiceException;
    
    public TransportInsertResult startInsertBefore(String pmId, String containerId, TransportPersistenceElement holder,
            String reference, String sessionId) throws ServiceException;
    
    public void startUpdate(String pmId, String containerId, TransportPersistenceElement holder, String sessionId)
            throws ServiceException;
    
    public void waitForIndexThreadsToFinish(String pmId, String sessionId) throws ServiceException;
    
}
