package com.clcbio.client.thin.helper;

import java.util.ArrayList;
import java.util.List;

import com.clcbio.client.thin.model.exceptions.SerializeableStackTraceElement;
import com.clcbio.client.thin.model.exceptions.ThinException;

/**
 * Due to the non serializeable nature of java.lang.Exception a Thin Exception
 * that can be serialized via getters and setters and default constructors (thus
 * bean serialization) is born.
 * 
 */
public class ThinExceptionHelper {

    private static void addToStackTrace(Throwable fatNonSerializeableException, List<SerializeableStackTraceElement> coolThinStackTrace) {
        StackTraceElement[] nonSerializeableStackTrace = fatNonSerializeableException.getStackTrace();
        for (int i = 0; i < nonSerializeableStackTrace.length; i++) {
            if (coolThinStackTrace.size() < 500) {
                coolThinStackTrace.add(new SerializeableStackTraceElement(nonSerializeableStackTrace[i]));
            }
            else {
                break;
            }
        }
        // System.out.println("StackTrace size: "+coolThinStackTrace.size());
        Throwable fatCause = fatNonSerializeableException.getCause();
        if (fatCause != null && fatCause != fatNonSerializeableException) {
            SerializeableStackTraceElement newLine = new SerializeableStackTraceElement();
            newLine.setFileName("");
            newLine.setLineNumber(0);
            newLine.setMethodName("");
            newLine.setDeclaringClass("\r\n\tatCaused by: " + stripNonValidXMLCharacters(fatCause.toString()));
            coolThinStackTrace.add(newLine);
            addToStackTrace(fatCause, coolThinStackTrace);
        }
    }

    public static void fromThickToThin(ThinException thinInstance, Throwable fatNonSerializeableException) {
        List<SerializeableStackTraceElement> coolThinStackTrace = new ArrayList<SerializeableStackTraceElement>();
        addToStackTrace(fatNonSerializeableException, coolThinStackTrace);
        thinInstance.setStacktrace(coolThinStackTrace);
        thinInstance.setMessage(stripNonValidXMLCharacters(fatNonSerializeableException.toString()));
        thinInstance.setExceptionClassName(stripNonValidXMLCharacters(fatNonSerializeableException.getClass().getName()));
    }

    /**
     * This method ensures that the output String has only valid XML unicode
     * characters as specified by the XML 1.0 standard. For reference, please
     * see <a href="http://www.w3.org/TR/2000/REC-xml-20001006#NT-Char">the
     * standard</a>. This method will return an empty String if the input is
     * null or empty.
     * 
     * @param in
     *            The String whose non-valid characters we want to remove.
     * @return The in String, stripped of non-valid characters.
     */
    public static String stripNonValidXMLCharacters(String in) {
        StringBuffer out = new StringBuffer(); // Used to hold the output.
        char current; // Used to reference the current character.

        if (in == null || ("".equals(in))) {
            return ""; // vacancy test.
        }
        for (int i = 0; i < in.length(); i++) {
            current = in.charAt(i); // NOTE: No IndexOutOfBoundsException caught
                                    // here; it should not happen.
            if ((current == 0x9) || (current == 0xA) || (current == 0xD) || ((current >= 0x20) && (current <= 0xD7FF))
                    || ((current >= 0xE000) && (current <= 0xFFFD)) || ((current >= 0x10000) && (current <= 0x10FFFF))) {
                out.append(current);
            }
        }
        return out.toString();
    }

}
