package com.clcbio.client.thin.model.admin.configuration;

import java.util.ArrayList;

import com.clcbio.client.thin.model.admin.configuration.subsystem.authentication.AuthenticationConfiguration;
import com.clcbio.client.thin.model.admin.configuration.subsystem.cluster.Node;
import com.clcbio.client.thin.model.admin.configuration.subsystem.cluster.SlaveNodeManagerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.subsystem.directcommand.DirectCommandConfiguration;
import com.clcbio.client.thin.model.admin.configuration.subsystem.grid.GridConfiguration;
import com.clcbio.client.thin.model.admin.configuration.subsystem.permission.ServerApiPermissionConfiguration;
import com.clcbio.client.thin.model.admin.configuration.subsystem.safefiles.SafeFileDirectories;
import com.clcbio.client.thin.model.admin.configuration.subsystem.templatecommand.TemplateCommandManagerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.subsystem.users.UserConfiguration;
import com.clcbio.client.thin.model.admin.configuration.subsystem.workflow.WorkflowConfiguration;
import com.clcbio.client.thin.model.admin.configuration.system.FileSystemPersistenceModelConf;
import com.clcbio.client.thin.model.admin.configuration.system.IndexServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.system.ModelConfiguration;
import com.clcbio.client.thin.model.admin.configuration.system.SMTPConfiguration;
import com.clcbio.client.thin.model.admin.configuration.system.ServerMainConfiguration;
import com.clcbio.client.thin.model.admin.configuration.system.SqlPersistenceModelConf;
import com.google.gwt.user.client.rpc.IsSerializable;

public enum ServerConfigurationModule implements IsSerializable {
    MAIN_SYSTEM(ServerMainConfiguration.class, "Server main configuration", "CLCServerConfigurationMain.xml", 1.2), SUBSYSTEM_CLUSTER(
            SlaveNodeManagerConfiguration.class, "Server Job node configuration", "CLCServerConfigurationCluster.xml", 1.2), SUBSYSTEM_TEMPLATE_COMMAND(
            TemplateCommandManagerConfiguration.class, "External applications configuration", "CLCServerConfigurationTemplate.xml",
            1.1), SUBSYSTEM_AUTH(AuthenticationConfiguration.class, "Server authentication configuration",
            "CLCServerConfigurationAuth.xml", 1.0), SUBSYSTEM_USERS(UserConfiguration.class, "Server users and groups configuration",
            "CLCServerConfigurationUsers.xml", 1.0), SUBSYSTEM_SAFE_FILES(SafeFileDirectories.class,
            "Import/Export directories configuration", "CLCServerConfigurationSafeFiles.xml", 1.1), SUBSYSTEM_GRID(
            GridConfiguration.class, "Grid Presets configuration", "CLCServerConfigurationGrid.xml", 1.1),
            SUBSYSTEM_API_PERMISSION(ServerApiPermissionConfiguration.class, "Server API permission configuration",
                    "CLCServerConfigurationApiPermission.xml", 1.2),
            SUBSYSTEM_DIRECT_COMMAND(DirectCommandConfiguration.class, "Server DirectCommand configuration",
                    "CLCServerConfigurationDirectCommand.xml", 1.0),
            SUBSYSTEM_WORKFLOW(WorkflowConfiguration.class, "Server Workflow configuration", "CLCServerConfigurationWorkflow.xml", 1.1), ;
    private String configurationTypeDescription;
    private String configurationTypeFileName;
    private Class implementingClass;
    private double configurationVersion;
    
    private ServerConfigurationModule(Class implementingClass, String configurationTypeDescription, String configurationFileName,
            double configurationVersion) {
        this.implementingClass = implementingClass;
        this.configurationTypeDescription = configurationTypeDescription;
        this.configurationTypeFileName = configurationFileName;
        this.configurationVersion = configurationVersion;
    }
    
    public String getConfigurationTypeDescription() {
        return configurationTypeDescription;
    }
    
    public String getConfigurationTypeFileName() {
        return createConfigurationTypeFileNameFromVersion(getConfigurationVersion());
    }
    
    public String createConfigurationTypeFileNameFromVersion(double confVersion) {
        return configurationTypeFileName.replace(".", String.valueOf(confVersion).replace('.', '-') + ".");
    }
    
    public Class getImplementingClass() {
        return implementingClass;
    }
    
    public double getConfigurationVersion() {
        return configurationVersion;
    }
    
    public ServerConfiguration createDefault() throws Exception {
        ServerConfiguration configuration = null;
        if (this.equals(MAIN_SYSTEM)) {
            configuration = createMain();
        }
        else if (this.equals(SUBSYSTEM_CLUSTER)) {
            configuration = createCluster();
        }
        else if (this.equals(SUBSYSTEM_TEMPLATE_COMMAND)) {
            configuration = new TemplateCommandManagerConfiguration();
        }
        else if (this.equals(SUBSYSTEM_AUTH)) {
            configuration = createAuth();
        }
        else if (this.equals(SUBSYSTEM_USERS)) {
            configuration = createUsers();
        }
        else if (this.equals(SUBSYSTEM_SAFE_FILES)) {
            configuration = new SafeFileDirectories();
        }
        else if (this.equals(SUBSYSTEM_GRID)) {
            configuration = new GridConfiguration();
        }
        else if (this.equals(SUBSYSTEM_API_PERMISSION)) {
            configuration = new ServerApiPermissionConfiguration();
        }
        else if (this.equals(SUBSYSTEM_DIRECT_COMMAND)) {
            configuration = new DirectCommandConfiguration();
        }
        else if (this.equals(SUBSYSTEM_WORKFLOW)) {
            configuration = new WorkflowConfiguration();
        }
        // does not work in GWT:
        // else{
        // configuration = (ServerConfiguration)
        // implementingClass.newInstance();
        // }
        return configuration;
    }
    
    private ServerConfiguration createCluster() throws Exception {
        SlaveNodeManagerConfiguration slaveConf = new SlaveNodeManagerConfiguration();
        slaveConf.setSlavenodes(new ArrayList<Node>());
        slaveConf.setMasterNode(new Node());
        return slaveConf;
    }
    
    private ServerConfiguration createAuth() throws Exception {
        AuthenticationConfiguration authConf = new AuthenticationConfiguration();
        return authConf;
    }
    
    private ServerConfiguration createUsers() throws Exception {
        UserConfiguration userConf = new UserConfiguration();
        return userConf;
    }
    
    private ServerConfiguration createMain() throws Exception {
        ServerMainConfiguration serverConfiguration = new ServerMainConfiguration();
        ModelConfiguration modelConfiguration = new ModelConfiguration();
        IndexServerConfiguration indexServerConfiguration = new IndexServerConfiguration();
        
        serverConfiguration.setIndexServerConfiguration(indexServerConfiguration);
        modelConfiguration.setSqlDbParameters(new SqlPersistenceModelConf[] {});
        modelConfiguration.setFileSystemPersistenceModels(new FileSystemPersistenceModelConf[] {});
        serverConfiguration.setUserSessionTimeOutSeconds(10 * 60);// 10 mins
        serverConfiguration.setMaxServletUploadSizeBytes(1024 * 1024 * 200);// 200Mb

        serverConfiguration.setModelConfiguration(modelConfiguration);
        serverConfiguration.setSmtpConfiguration(new SMTPConfiguration());
        return serverConfiguration;
    }
    
}