package com.clcbio.client.thin.model.admin.configuration.subsystem.authentication;

import java.util.HashMap;
import java.util.Map;

import com.clcbio.client.thin.model.CommonBeanSerialization;

public class AdConfiguration implements CommonBeanSerialization {
    private static final long serialVersionUID = 7382063518158314121L;
    public static String KEY_HOST = "ad_host";
    public static String KEY_PORT = "ad_port";
    public static String KEY_DOMAIN = "ad_domain";
    public static String KEY_GROUPS_DN = "ad_groups_dn";
    public static String KEY_USERS_DN = "ad_users_dn";
    public static String KEY_ADMIN_GROUP = "ad_admin_group";
    public static final String KEY_CACHE = "auth_cache_time";

    private String host, domain, adminGroup, groupsDN, usersDN;
    private int port, cacheTimeout;

    public AdConfiguration() {
        host = "";
        port = 389;
        domain = "";
        adminGroup = "Domain Admins";
        cacheTimeout = 3600;
        usersDN = "";
        groupsDN = "";
    }

    public String getHost() {
        return host;
    }

    public void setHost(String host) {
        this.host = host;
    }

    public String getDomain() {
        return domain;
    }

    public void setDomain(String domain) {
        this.domain = domain;
    }

    public String getAdminGroup() {
        return adminGroup;
    }

    public void setAdminGroup(String adminGroup) {
        this.adminGroup = adminGroup;
    }

    public int getPort() {
        return port;
    }

    public void setPort(int port) {
        this.port = port;
    }

    public int getCacheTimeout() {
        return cacheTimeout;
    }

    public void setCacheTimeout(int cacheTimeout) {
        this.cacheTimeout = cacheTimeout;
    }

    public String getGroupsDN() {
        return groupsDN;
    }

    public void setGroupsDN(String groupsDN) {
        this.groupsDN = groupsDN;
    }

    public String getUsersDN() {
        return usersDN;
    }

    public void setUsersDN(String usersDN) {
        this.usersDN = usersDN;
    }

    public Map<String, String> getAsMap() {
        Map<String, String> configMap = new HashMap<String, String>();
        configMap.put(KEY_HOST, host);
        configMap.put(KEY_PORT, "" + port);
        configMap.put(KEY_ADMIN_GROUP, adminGroup);
        configMap.put(KEY_DOMAIN, domain);
        configMap.put(KEY_CACHE, "" + cacheTimeout);
        configMap.put(KEY_USERS_DN, usersDN);
        configMap.put(KEY_GROUPS_DN, groupsDN);
        return configMap;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((adminGroup == null) ? 0 : adminGroup.hashCode());
        result = prime * result + cacheTimeout;
        result = prime * result + ((domain == null) ? 0 : domain.hashCode());
        result = prime * result + ((groupsDN == null) ? 0 : groupsDN.hashCode());
        result = prime * result + ((host == null) ? 0 : host.hashCode());
        result = prime * result + port;
        result = prime * result + ((usersDN == null) ? 0 : usersDN.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        AdConfiguration other = (AdConfiguration) obj;
        if (adminGroup == null) {
            if (other.adminGroup != null) {
                return false;
            }
        }
        else if (!adminGroup.equals(other.adminGroup)) {
            return false;
        }
        if (cacheTimeout != other.cacheTimeout) {
            return false;
        }
        if (domain == null) {
            if (other.domain != null) {
                return false;
            }
        }
        else if (!domain.equals(other.domain)) {
            return false;
        }
        if (groupsDN == null) {
            if (other.groupsDN != null) {
                return false;
            }
        }
        else if (!groupsDN.equals(other.groupsDN)) {
            return false;
        }
        if (host == null) {
            if (other.host != null) {
                return false;
            }
        }
        else if (!host.equals(other.host)) {
            return false;
        }
        if (port != other.port) {
            return false;
        }
        if (usersDN == null) {
            if (other.usersDN != null) {
                return false;
            }
        }
        else if (!usersDN.equals(other.usersDN)) {
            return false;
        }
        return true;
    }

    public AdConfiguration clone(){
        AdConfiguration clone = new AdConfiguration();
        clone.setHost(host);
        clone.setDomain(domain);
        clone.setAdminGroup(adminGroup);
        clone.setGroupsDN(groupsDN);
        clone.setUsersDN(usersDN);
        clone.setPort(port);
        clone.setCacheTimeout(cacheTimeout);
        return clone;
    }
    
    @Override
    public String toString() {
        return "AdConfiguration [adminGroup=" + adminGroup + ", cacheTimeout=" + cacheTimeout + ", domain=" + domain + ", groupsDN="
                + groupsDN + ", host=" + host + ", port=" + port + ", usersDN=" + usersDN + "]";
    }

}