package com.clcbio.client.thin.model.admin.configuration.subsystem.authentication;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.admin.configuration.GwtClone;
import com.clcbio.client.thin.model.admin.configuration.ServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.ServerConfigurationModule;

public class AuthenticationConfiguration extends ServerConfiguration implements CommonBeanSerialization, GwtClone {

    private static final long serialVersionUID = 1884050727201150124L;
    public static final String AUTH_LDAP = "ldap";
    public static final String AUTH_AD = "ad";
    public static final String AUTH_BUILTIN = "builtin";

    private String mechamism;
    private LdapConfiguration ldapConfiguration;
    private AdConfiguration adConfiguration;

    public AuthenticationConfiguration() {
        this.ldapConfiguration = new LdapConfiguration();
        this.adConfiguration = new AdConfiguration();
        this.mechamism = AUTH_BUILTIN;
    }

    public AuthenticationConfiguration(String mechamism, LdapConfiguration ldapConfiguration, AdConfiguration adConfiguration) {
        super();
        this.mechamism = mechamism;
        this.ldapConfiguration = ldapConfiguration;
        this.adConfiguration = adConfiguration;
    }

    public String getMechamism() {
        return mechamism;
    }

    public void setMechamism(String mechamism) {
        this.mechamism = mechamism;
    }

    public LdapConfiguration getLdapConfiguration() {
        return ldapConfiguration;
    }

    public void setLdapConfiguration(LdapConfiguration ldapConfiguration) {
        this.ldapConfiguration = ldapConfiguration;
    }

    public AdConfiguration getAdConfiguration() {
        return adConfiguration;
    }

    public void setAdConfiguration(AdConfiguration adConfiguration) {
        this.adConfiguration = adConfiguration;
    }

    @Override
    public ServerConfigurationModule getModuleType() {
        return ServerConfigurationModule.SUBSYSTEM_AUTH;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((adConfiguration == null) ? 0 : adConfiguration.hashCode());
        result = prime * result + ((ldapConfiguration == null) ? 0 : ldapConfiguration.hashCode());
        result = prime * result + ((mechamism == null) ? 0 : mechamism.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        AuthenticationConfiguration other = (AuthenticationConfiguration) obj;
        if (adConfiguration == null) {
            if (other.adConfiguration != null) {
                return false;
            }
        }
        else if (!adConfiguration.equals(other.adConfiguration)) {
            return false;
        }
        if (ldapConfiguration == null) {
            if (other.ldapConfiguration != null) {
                return false;
            }
        }
        else if (!ldapConfiguration.equals(other.ldapConfiguration)) {
            return false;
        }
        if (mechamism == null) {
            if (other.mechamism != null) {
                return false;
            }
        }
        else if (!mechamism.equals(other.mechamism)) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "AuthenticationConfiguration [adConfiguration=" + adConfiguration + ", ldapConfiguration=" + ldapConfiguration
                + ", mechamism=" + mechamism + "]";
    }
    
    public ServerConfiguration createClone() {
        AuthenticationConfiguration clone = new AuthenticationConfiguration(mechamism, ldapConfiguration.clone(), adConfiguration.clone());
        return clone;
    }

}
