package com.clcbio.client.thin.model.admin.configuration.subsystem.authentication;

import java.util.HashMap;
import java.util.Map;

import com.clcbio.client.thin.model.CommonBeanSerialization;

public class LdapConfiguration implements CommonBeanSerialization {
    private static final long serialVersionUID = 6294393813508701356L;
    public static final String KEY_HOST = "ldap_host";
    public static final String KEY_PORT = "ldap_port";
    public static final String KEY_BASE_DN = "ldap_base_dn";
    public static final String KEY_UID_ATTR = "ldap_uid_attr";
    public static final String KEY_USER_DN = "ldap_user_dn";
    public static final String KEY_USER_SCOPE = "ldap_user_scope";
    public static final String KEY_GROUP_DN = "ldap_group_dn";
    public static final String KEY_GROUP_SCOPE = "ldap_group_scope";
    public static final String KEY_GID_ATTR = "ldap_gid_attr";
    public static final String KEY_MEMBER_ATTR = "ldap_member_attr";
    public static final String KEY_ADMIN_GID = "ldap_admin_group";
    public static final String KEY_BIND_DN = "ldap_bind_dn";
    public static final String KEY_BIND_PASSWORD = "ldap_bind_pw";
    public static final String KEY_CACHE = "auth_cache_time";
    public static final String KEY_GSSAPI = "ldap_gssapi";
    public static final String KEY_REALM = "ldap_realm";
    public static final String KEY_KRB_CONFIG = "ldap_krb_config";
    public static final String KEY_SSL = "ldap_ssl";
    

    private String host, baseDN, adminGroup, usersDN, groupsDN, uidAttr, groupNameAttr, membershipAttr, bindDN, bindPassword, realm, krbConfig;
    private int port, cacheTimeout;
    private boolean anonymousBind, gssapi, ssl;

    public LdapConfiguration() {
        host = "";
        port = 389;
        baseDN = "";
        adminGroup = "admins";
        usersDN = "ou=users";
        groupsDN = "ou=groups";
        uidAttr = "uid";
        groupNameAttr = "cn";
        membershipAttr = "memberUid";
        bindDN = "";
        bindPassword = "";
        cacheTimeout = 3600;
        gssapi = false;
        realm= "";
        krbConfig = "/etc/krb5.conf";
        ssl = false;
    }

    public String getHost() {
        return host;
    }

    public void setHost(String host) {
        this.host = host;
    }

    public String getBaseDN() {
        return baseDN;
    }

    public void setBaseDN(String baseDN) {
        this.baseDN = baseDN;
    }

    public String getAdminGroup() {
        return adminGroup;
    }

    public void setAdminGroup(String adminGroup) {
        this.adminGroup = adminGroup;
    }

    public String getUsersDN() {
        return usersDN;
    }

    public void setUsersDN(String usersDN) {
        this.usersDN = usersDN;
    }

    public String getGroupsDN() {
        return groupsDN;
    }

    public void setGroupsDN(String groupsDN) {
        this.groupsDN = groupsDN;
    }

    public String getUidAttr() {
        return uidAttr;
    }

    public void setUidAttr(String uidAttr) {
        this.uidAttr = uidAttr;
    }

    public String getGroupNameAttr() {
        return groupNameAttr;
    }

    public void setGroupNameAttr(String groupNameAttr) {
        this.groupNameAttr = groupNameAttr;
    }

    public String getMembershipAttr() {
        return membershipAttr;
    }

    public void setMembershipAttr(String membershipAttr) {
        this.membershipAttr = membershipAttr;
    }

    public String getBindDN() {
        return bindDN;
    }

    public void setBindDN(String bindDN) {
        this.bindDN = bindDN;
    }

    public String getBindPassword() {
        return bindPassword;
    }

    public void setBindPassword(String bindPassword) {
        this.bindPassword = bindPassword;
    }

    public int getPort() {
        return port;
    }

    public void setPort(int port) {
        this.port = port;
    }

    public int getCacheTimeout() {
        return cacheTimeout;
    }

    public void setCacheTimeout(int cacheTimeout) {
        this.cacheTimeout = cacheTimeout;
    }

    public boolean isAnonymousBind() {
        return anonymousBind;
    }

    public void setAnonymousBind(boolean anonymousBind) {
        this.anonymousBind = anonymousBind;
    }
    
    public String getRealm() {
        return realm;
    }

    public void setRealm(String realm) {
        this.realm = realm;
    }

    public String getKrbConfig() {
        return krbConfig;
    }

    public void setKrbConfig(String krbConfig) {
        this.krbConfig = krbConfig;
    }

    public boolean isGssapi() {
        return gssapi;
    }

    public void setGssapi(boolean gssapi) {
        this.gssapi = gssapi;
    }
    
    public boolean isSsl() {
        return ssl;
    }

    public void setSsl(boolean ssl) {
        this.ssl = ssl;
    }

    public Map<String, String> getAsMap() {
        Map<String, String> configMap = new HashMap<String, String>();
        configMap.put(KEY_HOST, host);
        configMap.put(KEY_PORT, "" + port);
        configMap.put(KEY_BASE_DN, baseDN);
        configMap.put(KEY_ADMIN_GID, adminGroup);
        configMap.put(KEY_BIND_DN, bindDN);
        configMap.put(KEY_BIND_PASSWORD, bindPassword);
        configMap.put(KEY_GID_ATTR, groupNameAttr);
        configMap.put(KEY_MEMBER_ATTR, membershipAttr);
        configMap.put(KEY_GROUP_DN, groupsDN);
        configMap.put(KEY_UID_ATTR, uidAttr);
        configMap.put(KEY_USER_DN, usersDN);
        configMap.put(KEY_CACHE, "" + cacheTimeout);
        configMap.put(KEY_GSSAPI, ""+gssapi);
        configMap.put(KEY_REALM, realm);
        configMap.put(KEY_KRB_CONFIG, krbConfig);
        configMap.put(KEY_SSL, ""+ssl);
        return configMap;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((adminGroup == null) ? 0 : adminGroup.hashCode());
        result = prime * result + (anonymousBind ? 1231 : 1237);
        result = prime * result + ((baseDN == null) ? 0 : baseDN.hashCode());
        result = prime * result + ((bindDN == null) ? 0 : bindDN.hashCode());
        result = prime * result + ((bindPassword == null) ? 0 : bindPassword.hashCode());
        result = prime * result + cacheTimeout;
        result = prime * result + ((groupNameAttr == null) ? 0 : groupNameAttr.hashCode());
        result = prime * result + ((groupsDN == null) ? 0 : groupsDN.hashCode());
        result = prime * result + ((host == null) ? 0 : host.hashCode());
        result = prime * result + ((membershipAttr == null) ? 0 : membershipAttr.hashCode());
        result = prime * result + port;
        result = prime * result + ((uidAttr == null) ? 0 : uidAttr.hashCode());
        result = prime * result + ((usersDN == null) ? 0 : usersDN.hashCode());
        result = prime * result + (gssapi ? 3215 : 15123);
        result = prime * result + ((realm == null) ? 0 : realm.hashCode());
        result = prime * result + ((krbConfig == null) ? 0 : krbConfig.hashCode());
        result = prime * result + (ssl ? 5215 : 45123);
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        LdapConfiguration other = (LdapConfiguration) obj;
        if (adminGroup == null) {
            if (other.adminGroup != null) {
                return false;
            }
        }
        else if (!adminGroup.equals(other.adminGroup)) {
            return false;
        }
        if (anonymousBind != other.anonymousBind) {
            return false;
        }
        if (baseDN == null) {
            if (other.baseDN != null) {
                return false;
            }
        }
        else if (!baseDN.equals(other.baseDN)) {
            return false;
        }
        if (bindDN == null) {
            if (other.bindDN != null) {
                return false;
            }
        }
        else if (!bindDN.equals(other.bindDN)) {
            return false;
        }
        if (bindPassword == null) {
            if (other.bindPassword != null) {
                return false;
            }
        }
        else if (!bindPassword.equals(other.bindPassword)) {
            return false;
        }
        if (cacheTimeout != other.cacheTimeout) {
            return false;
        }
        if (groupNameAttr == null) {
            if (other.groupNameAttr != null) {
                return false;
            }
        }
        else if (!groupNameAttr.equals(other.groupNameAttr)) {
            return false;
        }
        if (groupsDN == null) {
            if (other.groupsDN != null) {
                return false;
            }
        }
        else if (!groupsDN.equals(other.groupsDN)) {
            return false;
        }
        if (host == null) {
            if (other.host != null) {
                return false;
            }
        }
        else if (!host.equals(other.host)) {
            return false;
        }
        if (membershipAttr == null) {
            if (other.membershipAttr != null) {
                return false;
            }
        }
        else if (!membershipAttr.equals(other.membershipAttr)) {
            return false;
        }
        if (port != other.port) {
            return false;
        }
        if (uidAttr == null) {
            if (other.uidAttr != null) {
                return false;
            }
        }
        else if (!uidAttr.equals(other.uidAttr)) {
            return false;
        }
        if (usersDN == null) {
            if (other.usersDN != null) {
                return false;
            }
        }
        else if (!usersDN.equals(other.usersDN)) {
            return false;
        }
        if (gssapi != other.gssapi) {
            return false;
        }
        else if (!realm.equals(other.realm)) {
            return false;
        }
        else if (!krbConfig.equals(other.krbConfig)) {
            return false;
        }
        if (ssl != other.ssl) {
            return false;
        }
        return true;
    }

    
    public LdapConfiguration clone(){
        LdapConfiguration clone = new LdapConfiguration();
        clone.setHost(host);
        clone.setBaseDN(baseDN);
        clone.setAdminGroup(adminGroup);
        clone.setUsersDN(usersDN);
        clone.setGroupsDN(groupsDN);
        clone.setUidAttr(uidAttr);
        clone.setGroupNameAttr(groupNameAttr);
        clone.setMembershipAttr(membershipAttr);
        clone.setBindDN(bindDN);
        clone.setBindPassword(bindPassword);
        clone.setPort(port);
        clone.setCacheTimeout(cacheTimeout);
        clone.setAnonymousBind(anonymousBind);
        clone.setGssapi(gssapi);
        clone.setRealm(realm);
        clone.setKrbConfig(krbConfig);
        clone.setSsl(ssl);
        return clone;
    }
    
    @Override
    public String toString() {
        return "LdapConfiguration [adminGroup=" + adminGroup + ", anonymousBind=" + anonymousBind + ", baseDN=" + baseDN + ", bindDN="
                + bindDN + ", cacheTimeout=" + cacheTimeout + ", groupNameAttr=" + groupNameAttr + ", groupsDN=" + groupsDN
                + ", host=" + host + ", membershipAttr=" + membershipAttr + ", port=" + port + ", uidAttr=" + uidAttr + ", usersDN="
                + usersDN + ", gssapi=" +gssapi+", realm="+realm+", krbConfig=" + krbConfig +", ssl=" + ssl + "]";
    }
}
