package com.clcbio.client.thin.model.admin.configuration.subsystem.cluster;

import java.util.ArrayList;
import java.util.List;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.admin.configuration.GwtClone;
import com.clcbio.client.thin.model.admin.configuration.ServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.ServerConfigurationModule;

public class SlaveNodeManagerConfiguration extends ServerConfiguration implements CommonBeanSerialization, GwtClone {
    private static final long serialVersionUID = -3614533476448952355L;
    private List<Node> slavenodes;
    private Node masterNode;
    private Node thisNode;
    private ServerState serverState;

    public SlaveNodeManagerConfiguration(List<Node> slavenodes, ServerState serverState, Node masterNode, Node thisNode) {
        super();
        this.slavenodes = slavenodes;
        this.serverState = serverState;
        this.masterNode = masterNode;
        this.thisNode = thisNode;
    }

    public SlaveNodeManagerConfiguration() {
        serverState = ServerState.SINGLE_SERVER;
        slavenodes = new ArrayList<Node>();
        masterNode = new Node();
        thisNode = new Node();
    }

    public Node getThisNode() {
        return thisNode;
    }

    public void setThisNode(Node thisNode) {
        this.thisNode = thisNode;
    }

    public ServerState getServerState() {
        return serverState;
    }

    public void setServerState(ServerState serverState) {
        this.serverState = serverState;
    }

    public List<Node> getSlavenodes() {
        return slavenodes;
    }

    public void setSlavenodes(List<Node> slavenodes) {
        this.slavenodes = slavenodes;
    }

    @Override
    public ServerConfigurationModule getModuleType() {
        return ServerConfigurationModule.SUBSYSTEM_CLUSTER;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((masterNode == null) ? 0 : masterNode.hashCode());
        result = prime * result + ((serverState == null) ? 0 : serverState.hashCode());
        result = prime * result + ((slavenodes == null) ? 0 : slavenodes.hashCode());
        result = prime * result + ((thisNode == null) ? 0 : thisNode.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        SlaveNodeManagerConfiguration other = (SlaveNodeManagerConfiguration) obj;
        if (masterNode == null) {
            if (other.masterNode != null) {
                return false;
            }
        }
        else if (!masterNode.equals(other.masterNode)) {
            return false;
        }
        if (serverState == null) {
            if (other.serverState != null) {
                return false;
            }
        }
        else if (!serverState.equals(other.serverState)) {
            return false;
        }
        if (slavenodes == null) {
            if (other.slavenodes != null) {
                return false;
            }
        }
        else if (!slavenodes.equals(other.slavenodes)) {
            return false;
        }
        if (thisNode == null) {
            if (other.thisNode != null) {
                return false;
            }
        }
        else if (!thisNode.equals(other.thisNode)) {
            return false;
        }
        return true;
    }

    public ServerConfiguration createClone() {
        ArrayList<Node> nodes = new ArrayList<Node>(getSlavenodes());
        SlaveNodeManagerConfiguration clone = new SlaveNodeManagerConfiguration(nodes, getServerState(), getMasterNode(),
                getThisNode());
        return clone;
    }

    @Override
    public String toString() {
        return "SlaveNodeManagerConfiuration ModuleType=" + getModuleType() + ",slavenodes=" + getSlavenodes() + ",ServerState="
                + getServerState() + ",masterNode=" + getMasterNode();
    }

    public Node getMasterNode() {
        return masterNode;
    }

    public void setMasterNode(Node masterNode) {
        this.masterNode = masterNode;
    }

}
