package com.clcbio.client.thin.model.admin.configuration.subsystem.permission;

import java.util.HashSet;
import java.util.Set;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.admin.configuration.subsystem.permission.GrantedGroupsKey;

/**
 * The allowed group names associated with an API permission configuration.
 * Can be enabled or disabled. 
 *
 */
public class GrantedGroups implements CommonBeanSerialization{
    private static final long serialVersionUID = -1338286638410755997L;
    private Set<String> nameOfGrantedGroups;
    private boolean permissionsEnabled;
    private GrantedGroupsKey childPermission;
    
    public GrantedGroups() {
        super();
        init();
    }

    private void init() {
        nameOfGrantedGroups = new HashSet<String>();
        permissionsEnabled = false;
        childPermission = null;
    }

    public GrantedGroups(GrantedGroups cloneFrom) {
        if(cloneFrom == null){
            init();
        }
        else{
            nameOfGrantedGroups = new HashSet<String>();
            permissionsEnabled = cloneFrom.isPermissionsEnabled();
            GrantedGroupsKey childPermissionSource = cloneFrom.getChildPermission();
            if(childPermissionSource == null){
                childPermission = null;;
            }
            else{
                childPermission = new GrantedGroupsKey(childPermissionSource);            
            }
            Set<String> noags = cloneFrom.getNameOfGrantedGroups();
            if(noags != null){
                nameOfGrantedGroups.addAll(noags);
            }            
        }
    }

    public GrantedGroupsKey getChildPermission() {
        return childPermission;
    }

    public void setChildPermission(GrantedGroupsKey childPermission) {
        this.childPermission = childPermission;
    }

    public boolean isPermissionsEnabled() {
        return permissionsEnabled;
    }

    public void setPermissionsEnabled(boolean permissionsEnabled) {
        this.permissionsEnabled = permissionsEnabled;
    }

    public Set<String> getNameOfGrantedGroups() {
        return nameOfGrantedGroups;
    }

    public void setNameOfGrantedGroups(Set<String> nameOfGrantedGroups) {
        this.nameOfGrantedGroups = nameOfGrantedGroups;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((childPermission == null) ? 0 : childPermission.hashCode());
        result = prime * result + ((nameOfGrantedGroups == null) ? 0 : nameOfGrantedGroups.hashCode());
        result = prime * result + (permissionsEnabled ? 1231 : 1237);
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        GrantedGroups other = (GrantedGroups) obj;
        if (childPermission == null) {
            if (other.childPermission != null)
                return false;
        }
        else if (!childPermission.equals(other.childPermission))
            return false;
        if (nameOfGrantedGroups == null) {
            if (other.nameOfGrantedGroups != null)
                return false;
        }
        else if (!nameOfGrantedGroups.equals(other.nameOfGrantedGroups))
            return false;
        if (permissionsEnabled != other.permissionsEnabled)
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "GrantedGroups [nameOfGrantedGroups=" + nameOfGrantedGroups + ", permissionsEnabled=" + permissionsEnabled
                + ", childPermission=" + childPermission + "]";
    }
 
}
