package com.clcbio.client.thin.model.admin.configuration.subsystem.permission;

import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.admin.configuration.GwtClone;
import com.clcbio.client.thin.model.admin.configuration.ServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.ServerConfigurationModule;

/**
 * The central configuration of permissions attached to 
 * selected parts of the server API.
 *
 */
public class ServerApiPermissionConfiguration extends ServerConfiguration implements CommonBeanSerialization, GwtClone {
    private static final long serialVersionUID = -1875156382641752380L;
    private Map<GrantedGroupsKey, GrantedGroups> permissionsMap;

    public ServerApiPermissionConfiguration() {
        super();
        permissionsMap = new HashMap<GrantedGroupsKey, GrantedGroups>();
    }

    public ServerConfiguration createClone() {
        ServerApiPermissionConfiguration clone = new ServerApiPermissionConfiguration();
        Set<Entry<GrantedGroupsKey, GrantedGroups>> confSet = permissionsMap.entrySet();
        for (Entry<GrantedGroupsKey, GrantedGroups> cmdEntry : confSet) {
            clone.getPermissionsMap().put(new GrantedGroupsKey(cmdEntry.getKey()), new GrantedGroups(cmdEntry.getValue()));
        }
        return clone;
    }

    public Map<GrantedGroupsKey, GrantedGroups> getPermissionsMap() {
        return permissionsMap;
    }

    public void setPermissionsMap(Map<GrantedGroupsKey, GrantedGroups> permissionsMap) {
        this.permissionsMap = permissionsMap;
    }

    @Override
    public ServerConfigurationModule getModuleType() {
        return ServerConfigurationModule.SUBSYSTEM_API_PERMISSION;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((permissionsMap == null) ? 0 : permissionsMap.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        ServerApiPermissionConfiguration other = (ServerApiPermissionConfiguration) obj;
        if (permissionsMap == null) {
            if (other.permissionsMap != null)
                return false;
        }
        else if (!permissionsMap.equals(other.permissionsMap))
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "ServerApiPermissionConfiguration [permissionsMap=" + permissionsMap + "]";
    }

}
