package com.clcbio.client.thin.model.admin.configuration.subsystem.users;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.admin.configuration.GwtClone;
import com.clcbio.client.thin.model.admin.configuration.ServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.ServerConfigurationModule;
import com.clcbio.client.thin.model.admin.configuration.subsystem.authentication.Group;

public class UserConfiguration extends ServerConfiguration implements CommonBeanSerialization, GwtClone {
    private static final long serialVersionUID = 7406151443519504846L;

    private static String DEFAULT_ADMIN_GROUP = "admin";

    private String rootPassword, adminGroup;
    private Map<String, String> userPasswordMap;
    private Map<String, Group> groupMap;

    public UserConfiguration() {
        this.rootPassword = "7505d64a54e061b7acd54ccd58b49dc43500b635";
        this.userPasswordMap = new HashMap<String, String>();
        this.groupMap = new HashMap<String, Group>();
        HashSet<String> m = new HashSet<String>();
        Group g = new Group(DEFAULT_ADMIN_GROUP, m);
        groupMap.put(DEFAULT_ADMIN_GROUP, g);
        adminGroup = DEFAULT_ADMIN_GROUP;
    }

    public UserConfiguration(String rootPassword, String adminGroup, Map<String, String> userPasswordMap, Map<String, Group> groupMap) {
        super();
        this.rootPassword = rootPassword;
        this.adminGroup = adminGroup;
        this.userPasswordMap = userPasswordMap;
        this.groupMap = groupMap;
    }

    public String getRootPassword() {
        return rootPassword;
    }

    public void setRootPassword(String rootPassword) {
        this.rootPassword = rootPassword;
    }

    public String getAdminGroup() {
        return adminGroup;
    }

    public void setAdminGroup(String adminGroup) {
        this.adminGroup = adminGroup;
    }

    public Map<String, String> getUserPasswordMap() {
        return userPasswordMap;
    }

    public void setUserPasswordMap(Map<String, String> userPasswordMap) {
        this.userPasswordMap = userPasswordMap;
    }

    public Map<String, Group> getGroupMap() {
        return groupMap;
    }

    public void setGroupMap(Map<String, Group> groupMap) {
        this.groupMap = groupMap;
    }

    @Override
    public ServerConfigurationModule getModuleType() {
        return ServerConfigurationModule.SUBSYSTEM_USERS;
    }

    public ServerConfiguration createClone() {
        Map<String, String> userPasswordClone = new HashMap<String, String>();
        Iterator<String> userIt = userPasswordMap.keySet().iterator();
        while(userIt.hasNext()){
            String key = userIt.next(); 
            userPasswordClone.put(key, userPasswordMap.get(key));
        }
        
        Map<String, Group> groupClone = new HashMap<String, Group>();
        Iterator<String> groupIt = groupMap.keySet().iterator();
        while(groupIt.hasNext()){
            String key = groupIt.next();
            groupClone.put(key, groupMap.get(key).clone());
        }
        return new UserConfiguration(rootPassword, adminGroup, userPasswordClone, groupClone);
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((adminGroup == null) ? 0 : adminGroup.hashCode());
        result = prime * result + ((groupMap == null) ? 0 : groupMap.hashCode());
        result = prime * result + ((rootPassword == null) ? 0 : rootPassword.hashCode());
        result = prime * result + ((userPasswordMap == null) ? 0 : userPasswordMap.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        UserConfiguration other = (UserConfiguration) obj;
        if (adminGroup == null) {
            if (other.adminGroup != null) {
                return false;
            }
        }
        else if (!adminGroup.equals(other.adminGroup)) {
            return false;
        }
        if (groupMap == null) {
            if (other.groupMap != null) {
                return false;
            }
        }
        else if (!groupMap.equals(other.groupMap)) {
            return false;
        }
        if (rootPassword == null) {
            if (other.rootPassword != null) {
                return false;
            }
        }
        else if (!rootPassword.equals(other.rootPassword)) {
            return false;
        }
        if (userPasswordMap == null) {
            if (other.userPasswordMap != null) {
                return false;
            }
        }
        else if (!userPasswordMap.equals(other.userPasswordMap)) {
            return false;
        }
        return true;
    }

}
