package com.clcbio.client.thin.model.admin.configuration.subsystem.workflow;

import java.util.ArrayList;
import java.util.List;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.admin.configuration.GwtClone;
import com.clcbio.client.thin.model.admin.configuration.ServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.ServerConfigurationModule;

public class WorkflowConfiguration extends ServerConfiguration implements CommonBeanSerialization, GwtClone {
    private static final long serialVersionUID = -1954345228286423628L;
    private List<InstalledWorkflowPlugin> installedWorkflowPlugins;

    public WorkflowConfiguration() {
        super();
        installedWorkflowPlugins = new ArrayList<InstalledWorkflowPlugin>();
    }

    public WorkflowConfiguration(WorkflowConfiguration cloneSource) {
        installedWorkflowPlugins = new ArrayList<InstalledWorkflowPlugin>();
        if(cloneSource != null){
            if(cloneSource.getInstalledWorkflowPlugins() != null){
                List<InstalledWorkflowPlugin> sourceList = cloneSource.getInstalledWorkflowPlugins();
                installedWorkflowPlugins = new ArrayList<InstalledWorkflowPlugin>();
                for (InstalledWorkflowPlugin sourceWorkflowPlugin : sourceList) {
                    installedWorkflowPlugins.add(new InstalledWorkflowPlugin(sourceWorkflowPlugin));
                }
            }
        }
    }

    public ServerConfiguration createClone() {
        return new WorkflowConfiguration(this);
    }

    public List<InstalledWorkflowPlugin> getInstalledWorkflowPlugins() {
        return installedWorkflowPlugins;
    }

    public void setInstalledWorkflowPlugins(List<InstalledWorkflowPlugin> installedWorkflowPlugins) {
        this.installedWorkflowPlugins = installedWorkflowPlugins;
    }

    @Override
    public ServerConfigurationModule getModuleType() {
        return ServerConfigurationModule.SUBSYSTEM_WORKFLOW;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((installedWorkflowPlugins == null) ? 0 : installedWorkflowPlugins.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        WorkflowConfiguration other = (WorkflowConfiguration) obj;
        if (installedWorkflowPlugins == null) {
            if (other.installedWorkflowPlugins != null)
                return false;
        }
        else if (!installedWorkflowPlugins.equals(other.installedWorkflowPlugins))
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "WorkflowConfiguration [installedWorkflowPlugins=" + installedWorkflowPlugins + "]";
    }

}
