package com.clcbio.client.thin.model.admin.configuration.system;

import java.util.Arrays;

import com.google.gwt.user.client.rpc.IsSerializable;

public class ModelConfiguration implements IsSerializable {
    private String[] supportedSqlDrivers;
    private String[] supportedSimpleDbDrivers;
    private SqlPersistenceModelConf[] sqlDbParameters;
    private SimpleDBPersistenceModelConf[] simpleDbParameters;
    private FileSystemPersistenceModelConf[] fileSystemPersistenceModels;
    
    public ModelConfiguration() {
        sqlDbParameters = new SqlPersistenceModelConf[0];
        fileSystemPersistenceModels = new FileSystemPersistenceModelConf[0];
        simpleDbParameters = new SimpleDBPersistenceModelConf[0];
    }
    
    public String[] getSupportedSqlDrivers() {
        return supportedSqlDrivers;
    }
    
    public void setSupportedSqlDrivers(String[] supportedSqlDrivers) {
        this.supportedSqlDrivers = supportedSqlDrivers;
    }
    
    public String[] getSupportedSimpleDbDrivers() {
        return supportedSimpleDbDrivers;
    }
    
    public void setSupportedSimpleDbDrivers(String[] supportedDrivers) {
        this.supportedSimpleDbDrivers = supportedDrivers;
    }
    
    public SimpleDBPersistenceModelConf[] getSimpleDbParameters() {
        return this.simpleDbParameters;
    }
    
    public void setSimpleDbParameters(SimpleDBPersistenceModelConf[] conf) {
        this.simpleDbParameters = conf;
    }
    
    public SqlPersistenceModelConf[] getSqlDbParameters() {
        return sqlDbParameters;
    }
    
    public void setSqlDbParameters(SqlPersistenceModelConf[] sqlDbParameters) {
        this.sqlDbParameters = sqlDbParameters;
    }
    
    public FileSystemPersistenceModelConf[] getFileSystemPersistenceModels() {
        return fileSystemPersistenceModels;
    }
    
    public void setFileSystemPersistenceModels(FileSystemPersistenceModelConf[] fileSystemPersistenceModels) {
        this.fileSystemPersistenceModels = fileSystemPersistenceModels;
    }
    
    public ModelConfiguration createClone() {
        ModelConfiguration clone = new ModelConfiguration();
        FileSystemPersistenceModelConf[] fClones = new FileSystemPersistenceModelConf[fileSystemPersistenceModels.length];
        for (int i = 0; i < fClones.length; i++) {
            fClones[i] = fileSystemPersistenceModels[i].createClone();
        }
        
        SqlPersistenceModelConf[] dbClones = new SqlPersistenceModelConf[sqlDbParameters.length];
        for (int i = 0; i < dbClones.length; i++) {
            dbClones[i] = sqlDbParameters[i].createClone();
        }
        
        SimpleDBPersistenceModelConf[] simpleDbClones = new SimpleDBPersistenceModelConf[simpleDbParameters.length];
        for (int i = 0; i < simpleDbClones.length; i++) {
            simpleDbClones[i] = simpleDbParameters[i].createClone();
        }
        
        clone.setSqlDbParameters(dbClones);
        clone.setSimpleDbParameters(simpleDbClones);
        clone.setSupportedSqlDrivers(supportedSqlDrivers);
        clone.setSupportedSimpleDbDrivers(supportedSimpleDbDrivers);
        clone.setFileSystemPersistenceModels(fClones);
        return clone;
    }
    
    @Override
    public String toString() {
        return "sqlDbParameters=" + Arrays.toString(sqlDbParameters) + ",fileSystemPersistenceModels="
                + Arrays.toString(fileSystemPersistenceModels);
    }
    
    @Override
    public boolean equals(Object obj) {
        if (obj instanceof ModelConfiguration) {
            ModelConfiguration otherConf = (ModelConfiguration) obj;
            boolean same = true;
            same = same && Arrays.equals(getFileSystemPersistenceModels(), otherConf.getFileSystemPersistenceModels());
            same = same && Arrays.equals(getSqlDbParameters(), otherConf.getSqlDbParameters());
            same = same && Arrays.equals(getSimpleDbParameters(), otherConf.getSimpleDbParameters());
            same = same && Arrays.equals(getSupportedSqlDrivers(), otherConf.getSupportedSqlDrivers());
            same = same && Arrays.equals(getSupportedSimpleDbDrivers(), otherConf.getSupportedSimpleDbDrivers());
            
            return same;
        }
        else {
            return false;
        }
    }
}
