package com.clcbio.client.thin.model.admin.configuration.system;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.admin.configuration.GwtClone;
import com.clcbio.client.thin.model.admin.configuration.ServerConfiguration;
import com.clcbio.client.thin.model.admin.configuration.ServerConfigurationModule;
import com.google.gwt.user.client.rpc.IsSerializable;

/**
 * Shared configuration Object
 * 
 * @author jschultz When expanding - remember to update gwtClone(), toString()
 *         and equals()...
 */
public class ServerMainConfiguration extends ServerConfiguration implements CommonBeanSerialization, GwtClone {
    private static final long serialVersionUID = 1722775595922339360L;
    public static final int minimumUerSessionTimeOutSeconds = 120;
    private int userSessionTimeOutSeconds;
    private long maxServletUploadSizeBytes;
    private ModelConfiguration modelConfiguration;
    private SMTPConfiguration smtpConfiguration;
    private IndexServerConfiguration indexServerConfiguration;

    public ServerMainConfiguration() {
        super();
        indexServerConfiguration = new IndexServerConfiguration();

    }

    public IndexServerConfiguration getIndexServerConfiguration() {
        return indexServerConfiguration;
    }

    public void setIndexServerConfiguration(IndexServerConfiguration indexServerConfiguration) {
        this.indexServerConfiguration = indexServerConfiguration;
    }

    /**
     * @return the userSessionTimeOutSeconds
     */
    public synchronized int getUserSessionTimeOutSeconds() {
        return userSessionTimeOutSeconds;
    }

    /**
     * @param userSessionTimeOutSeconds
     *            the userSessionTimeOutSeconds to set
     */
    public synchronized void setUserSessionTimeOutSeconds(int userSessionTimeOutSeconds) {
        this.userSessionTimeOutSeconds = userSessionTimeOutSeconds;
    }

    /**
     * @return the maxServletUploadSizeBytes
     */
    public synchronized long getMaxServletUploadSizeBytes() {
        return maxServletUploadSizeBytes;
    }

    /**
     * @param maxServletUploadSizeBytes
     *            the maxServletUploadSizeBytes to set
     */
    public synchronized void setMaxServletUploadSizeBytes(long maxServletUploadSizeBytes) {
        this.maxServletUploadSizeBytes = maxServletUploadSizeBytes;
    }

    public SMTPConfiguration getSmtpConfiguration() {
        return smtpConfiguration;
    }

    public void setSmtpConfiguration(SMTPConfiguration smtpConfiguration) {
        this.smtpConfiguration = smtpConfiguration;
    }

    public ModelConfiguration getModelConfiguration() {
        return modelConfiguration;
    }

    public void setModelConfiguration(ModelConfiguration modelConfiguration) {
        this.modelConfiguration = modelConfiguration;
    }

    @Override
    public String toString() {
        return "userSessionTimeOutSeconds=" + Integer.toString(userSessionTimeOutSeconds) + ",maxServletUploadSizeBytes="
                + Long.toString(maxServletUploadSizeBytes) + ",modelConfiguration="
                + (modelConfiguration == null ? "" : modelConfiguration.toString())
                + ",smtpConfiguration="
                + (smtpConfiguration == null ? "" : smtpConfiguration.toString()) + ",indexServerConfiguration="
                + indexServerConfiguration;
    }

    /*
     * Would have used clone, but this is not allowed in GWT serialized objects
     */
    public ServerMainConfiguration createClone() {
        ServerMainConfiguration clone = new ServerMainConfiguration();
        clone.setMaxServletUploadSizeBytes(maxServletUploadSizeBytes);
        clone.setUserSessionTimeOutSeconds(userSessionTimeOutSeconds);
        clone.setModelConfiguration(modelConfiguration.createClone());
        clone.setSmtpConfiguration(smtpConfiguration.createClone());
        clone.setIndexServerConfiguration(getIndexServerConfiguration());
        return clone;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj instanceof ServerMainConfiguration) {
            ServerMainConfiguration otherConf = (ServerMainConfiguration) obj;
            boolean same = true;
            same = same && getMaxServletUploadSizeBytes() == otherConf.getMaxServletUploadSizeBytes();
            same = same && getModelConfiguration().equals(otherConf.getModelConfiguration());
            same = same && getUserSessionTimeOutSeconds() == otherConf.getUserSessionTimeOutSeconds();
            same = same && getSmtpConfiguration().equals(otherConf.getSmtpConfiguration());
            same = same && getIndexServerConfiguration().equals(otherConf.getIndexServerConfiguration());
            return same;
        }
        else {
            return false;
        }
    }

    @Override
    public ServerConfigurationModule getModuleType() {
        return ServerConfigurationModule.MAIN_SYSTEM;
    }
}
