package com.clcbio.client.thin.model.bugsubmission;

import com.clcbio.client.thin.model.CommonBeanSerialization;

public enum DiagnosticsCheckType implements CommonBeanSerialization {
    
    JOB_NODE_SERVER_VERSION_EQUALITY("Master and job nodes version match", "Checks if master "
            + "and job nodes are running the same version" + " of the server"),
    
    JOB_NODE_COMMAND_EQUALITY(
            "Job distribution",
            "Checks if there are any type of jobs that do not have a job node or grid to run on. "
                    + "This is done by checking the job node configuration and by checking"
                    + " that the job node in question has the right plug-in installed in the right version or that a grid preset is present."),
    
    JOB_NODE_FILE_PERSISTENCE_MODEL_EQUALITY("File system locations consistency",
            "Checks if file system locations defined on the master node "
                    + "point to the same underlying file system on all job nodes."),
    
    JOB_NODE_CONFIGURATION_EQUALITY(
            "Job nodes configuration integrity",
            "Checks consistency of all configuration files of master and job n"
                    + "odes. The configurations checked are all those that can be managed under the Admin-tab. "
                    + "These configuration files (except for the job node configuration itself) must be identical on master and job nodes."),
    
    JOB_NODE_PLUGIN_EQUALITY("Job nodes plugin integrity", "Checks that the list of plug-ins installed on master and "
            + "job nodes is identical in terms of plug-in names and versions."),
    
    INDEX_SERVER_STATUS("Index server status", "Reports the status of the index server on master and job nodes. "
            + "The index server maintains an index of all data to be used for " + "searching."),
    
    FILE_PERSISTENCE_ID_MAP_PERMISSIONS("File system locations permissions",
            "Examines essential file permissions on shared file system location files. "
                    + "If servers are executed as different OS-users on same mounted file system, permission errors may occur.."),
    
    GRID_SETUP_STATUS("Grid setup status", "Checks all native library setups for grid integration"),
    
    FILE_PERSISTENCE_SAFE_FILES("Import/Export directories and file system location overlap",
            "Check if any file system locations overlap with any import/export locations, as this is not allowed.");
    
    private String headline;
    private String descriptionOfWhatIsTested;
    
    private DiagnosticsCheckType(String headline, String descriptionOfWhatIsTested) {
        this.headline = headline;
        this.descriptionOfWhatIsTested = descriptionOfWhatIsTested;
    }
    
    public String getHeadline() {
        return headline;
    }
    
    public String getDescriptionOfWhatIsTested() {
        return descriptionOfWhatIsTested;
    }
    
}
