package com.clcbio.client.thin.model.bugsubmission;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.log.LogQuery;

public class SystemInformationQuery implements CommonBeanSerialization {
    private static final long serialVersionUID = 6340412415493229919L;
    private LogQuery auditLogQuery;
    private boolean queryAuditlog;
    private boolean queryConfigurations;
    private boolean queryServerLogFiles;
    private boolean queryServerCheckSetupStatus;
    private SystemInformationQuery jobnodesQuery;
    private String addStaticUserStackTrace;
    private String addStaticUserErrorDescription;
    private String addStaticUserEmailAddress;

    public SystemInformationQuery() {
        super();
        auditLogQuery = createDefaultForBugSubmission();
        queryAuditlog = true;
        queryConfigurations = true;
        queryServerLogFiles = true;
        queryServerCheckSetupStatus = true;
        jobnodesQuery = null;
        addStaticUserStackTrace = "";
        addStaticUserErrorDescription = "";
        addStaticUserEmailAddress = "";
    }

    public LogQuery getAuditLogQuery() {
        return auditLogQuery;
    }

    public void setAuditLogQuery(LogQuery auditLogQuery) {
        this.auditLogQuery = auditLogQuery;
    }

    private LogQuery createDefaultForBugSubmission() {
        // get audit logs; Max 500, max one week old
        LogQuery q = new LogQuery();
        long now = System.currentTimeMillis();
        long oneWeek = 604800000l;
        q.setWindowFrom(1);
        q.setWindowTo(500);
        q.setOnOrAfterThisDate(now - oneWeek);
        return q;
    }

    public boolean isQueryAuditlog() {
        return queryAuditlog;
    }

    public void setQueryAuditlog(boolean queryAuditlog) {
        this.queryAuditlog = queryAuditlog;
    }

    public boolean isQueryConfigurations() {
        return queryConfigurations;
    }

    public void setQueryConfigurations(boolean queryConfigurations) {
        this.queryConfigurations = queryConfigurations;
    }

    public boolean isQueryServerLogFiles() {
        return queryServerLogFiles;
    }

    public void setQueryServerLogFiles(boolean queryServerLogFiles) {
        this.queryServerLogFiles = queryServerLogFiles;
    }

    public SystemInformationQuery getJobnodesQuery() {
        return jobnodesQuery;
    }

    public void setJobnodesQuery(SystemInformationQuery jobnodesQuery) {
        this.jobnodesQuery = jobnodesQuery;
    }

    public String getAddStaticUserStackTrace() {
        return addStaticUserStackTrace;
    }

    public void setAddStaticUserStackTrace(String addStaticUserStackTrace) {
        this.addStaticUserStackTrace = addStaticUserStackTrace;
    }

    public String getAddStaticUserErrorDescription() {
        return addStaticUserErrorDescription;
    }

    public void setAddStaticUserErrorDescription(String addStaticUserErrorDescription) {
        this.addStaticUserErrorDescription = addStaticUserErrorDescription;
    }

    public String getAddStaticUserEmailAddress() {
        return addStaticUserEmailAddress;
    }

    public void setAddStaticUserEmailAddress(String addStaticUserEmailAddress) {
        this.addStaticUserEmailAddress = addStaticUserEmailAddress;
    }

    public boolean isQueryServerCheckSetupStatus() {
        return queryServerCheckSetupStatus;
    }

    public void setQueryServerCheckSetupStatus(boolean queryServerCheckSetupStatus) {
        this.queryServerCheckSetupStatus = queryServerCheckSetupStatus;
    }

}
