package com.clcbio.client.thin.model.command;

import java.util.HashMap;
import java.util.Set;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.executionenvironment.ServerCLCExecutionEnvironment;
import com.clcbio.client.thin.model.executionenvironment.ServerExecutionEnvironment;
import com.clcbio.client.thin.model.legacy.CLCObjectReferences;

public class ServerCommandParameters implements CommonBeanSerialization {
    private static final long serialVersionUID = -5001222789760782178L;
    @SuppressWarnings("rawtypes")
    private HashMap parameters;
    private ServerExecutionEnvironment executionEnvironment;
    private NotificationPreferences notificationPreferences;
    
    public ServerCommandParameters() {
        super();
        executionEnvironment = new ServerCLCExecutionEnvironment();
        notificationPreferences = new NotificationPreferences();
        parameters = null;
    }

    @SuppressWarnings({ "rawtypes", "unchecked" })
    public ServerCommandParameters(ServerCommandParameters cloneFrom) {
        HashMap cloneMap = null;
        HashMap source = cloneFrom.getParameters();;
        if (source != null) {
            cloneMap = new HashMap();
            Set keys = source.keySet();
            for (Object key : keys) {
                Object val = source.get(key);
                // prevent logging of large binary objects
                if (val instanceof CLCObjectReferences) {
                    cloneMap.put(key, ((CLCObjectReferences) val).clone4log());
                }
                else {
                    cloneMap.put(key, val);
                }
            }
        }
        this.parameters = cloneMap;
        this.executionEnvironment = cloneFrom.getExecutionEnvironment().clone4log();
        this.notificationPreferences = cloneFrom.getNotificationPreferences().clone4log();

    }

    @SuppressWarnings("rawtypes")
    public HashMap getParameters() {
        return parameters;
    }

    @SuppressWarnings("rawtypes")
    public void setParameters(HashMap parameters) {
        this.parameters = parameters;
    }

    public ServerExecutionEnvironment getExecutionEnvironment() {
        return executionEnvironment;
    }

    public void setExecutionEnvironment(ServerExecutionEnvironment executionEnvironment) {
        this.executionEnvironment = executionEnvironment;
    }

    public NotificationPreferences getNotificationPreferences() {
        return notificationPreferences;
    }

    public void setNotificationPreferences(NotificationPreferences notificationPreferences) {
        this.notificationPreferences = notificationPreferences;
    }

    /*
     * Return a clone with reasonable values for logging
     */
    public ServerCommandParameters clone4log() {
        return new ServerCommandParameters(this);
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((executionEnvironment == null) ? 0 : executionEnvironment.hashCode());
        result = prime * result + ((notificationPreferences == null) ? 0 : notificationPreferences.hashCode());
        result = prime * result + ((parameters == null) ? 0 : parameters.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        ServerCommandParameters other = (ServerCommandParameters) obj;
        if (executionEnvironment == null) {
            if (other.executionEnvironment != null)
                return false;
        }
        else if (!executionEnvironment.equals(other.executionEnvironment))
            return false;
        if (notificationPreferences == null) {
            if (other.notificationPreferences != null)
                return false;
        }
        else if (!notificationPreferences.equals(other.notificationPreferences))
            return false;
        if (parameters == null) {
            if (other.parameters != null)
                return false;
        }
        else if (!parameters.equals(other.parameters))
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "ServerCommandParameters [parameters=" + parameters + ", executionEnvironment=" + executionEnvironment
                + ", notificationPreferences=" + notificationPreferences + "]";
    }

}
