package com.clcbio.client.thin.model.command;

import com.clcbio.client.thin.model.CommonBeanSerialization;

public class ServerCommandReference implements CommonBeanSerialization {
    private static final long serialVersionUID = -4366579000904408938L;
    private String id;
    private String name;
    private double version;
    private ServerCommandParameters commandParameters;
    private ServerCommandOutput commandOutputType;
    private boolean isMasterCommand;

    public ServerCommandReference(ServerCommandReference cloneFrom) {
        super();
        this.id = cloneFrom.getId();
        this.name = cloneFrom.getName();
        this.commandParameters = cloneFrom.getCommandParameters() == null ? null : cloneFrom
                .getCommandParameters().clone4log();
        this.commandOutputType = cloneFrom.getCommandOutputType() == null ? null : cloneFrom.getCommandOutputType()
                .clone4log();
        this.version = cloneFrom.getVersion();
        this.isMasterCommand = cloneFrom.isMasterCommand();
    }

    public ServerCommandReference() {
        super();
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public ServerCommandParameters getCommandParameters() {
        return commandParameters;
    }

    public void setCommandParameters(ServerCommandParameters commandParameters) {
        this.commandParameters = commandParameters;
    }

    public ServerCommandOutput getCommandOutputType() {
        return commandOutputType;
    }

    public void setCommandOutputType(ServerCommandOutput commandOutputType) {
        this.commandOutputType = commandOutputType;
    }

    public double getVersion() {
        return version;
    }

    public void setVersion(double version) {
        this.version = version;
    }

    @Override
    public String toString() {
        return "name=" + name + ", id=" + id + ",commandParameters=" + commandParameters + ",commandOutputType=" + commandOutputType
                + ",version=" + version + ",isMasterCommand=" + isMasterCommand;
    }

    /*
     * Return a clone with reasonable values for logging
     */
    public ServerCommandReference clone4log() {
        return new ServerCommandReference(this);
    }

    public boolean isMasterCommand() {
        return isMasterCommand;
    }

    public void setMasterCommand(boolean isMasterCommand) {
        this.isMasterCommand = isMasterCommand;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((commandOutputType == null) ? 0 : commandOutputType.hashCode());
        result = prime * result + ((commandParameters == null) ? 0 : commandParameters.hashCode());
        result = prime * result + ((id == null) ? 0 : id.hashCode());
        result = prime * result + (isMasterCommand ? 1231 : 1237);
        result = prime * result + ((name == null) ? 0 : name.hashCode());
        long temp;
        temp = String.valueOf(version).hashCode();
        result = prime * result + (int) (temp ^ (temp >>> 32));
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        ServerCommandReference other = (ServerCommandReference) obj;
        if (commandOutputType == null) {
            if (other.commandOutputType != null)
                return false;
        }
        else if (!commandOutputType.equals(other.commandOutputType))
            return false;
        if (commandParameters == null) {
            if (other.commandParameters != null)
                return false;
        }
        else if (!commandParameters.equals(other.commandParameters))
            return false;
        if (id == null) {
            if (other.id != null)
                return false;
        }
        else if (!id.equals(other.id))
            return false;
        if (isMasterCommand != other.isMasterCommand)
            return false;
        if (name == null) {
            if (other.name != null)
                return false;
        }
        else if (!name.equals(other.name))
            return false;
        if (version != other.version)
            return false;
        return true;
    }

}
