package com.clcbio.client.thin.model.command.algo;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;
import java.util.Set;

import com.clcbio.client.thin.model.command.ServerCommandParameters;
import com.clcbio.client.thin.model.command.algo.parameter.AlgoParameterBean;

public class ServerCommandAlgoParameters extends ServerCommandParameters {
    private static final long serialVersionUID = 2655212009334697099L;
    private List<ServerAlgoChannelInput> serverAlgoInputChannels;
    private List<ServerAlgoDestination> serverAlgoDestinations;

    private Map<String, AlgoParameterBean> algoBeanParameters;

    private boolean useGroupedOutput;
    private boolean logAlways;

    public ServerCommandAlgoParameters() {
        super();
        algoBeanParameters = new HashMap<String, AlgoParameterBean>();
        serverAlgoInputChannels = new ArrayList<ServerAlgoChannelInput>();
        serverAlgoDestinations = new ArrayList<ServerAlgoDestination>();
        useGroupedOutput = false;
        logAlways = true;
    }

    public ServerCommandAlgoParameters(ServerCommandAlgoParameters cloneFrom) {
        super(cloneFrom);
        
        algoBeanParameters = new HashMap<String, AlgoParameterBean>();
        serverAlgoInputChannels = new ArrayList<ServerAlgoChannelInput>();
        serverAlgoDestinations = new ArrayList<ServerAlgoDestination>();

        Map<String, AlgoParameterBean> algoParamSource = cloneFrom.getAlgoBeanParameters();
        if(algoParamSource != null){
            Set<Entry<String, AlgoParameterBean>> set = algoParamSource.entrySet();
            for (Entry<String, AlgoParameterBean> entry : set) {
                algoBeanParameters.put(entry.getKey(), entry.getValue().clone4log());
            }
        }
        List<ServerAlgoDestination> destSource = cloneFrom.getServerAlgoDestinations();
        if(destSource != null){
            for (ServerAlgoDestination serverAlgoDestination : destSource) {
                serverAlgoDestinations.add(serverAlgoDestination.clone4log());
            }            
        }
        List<ServerAlgoChannelInput> inputSources = cloneFrom.getServerAlgoInputChannels();
        if(inputSources != null){
            for (ServerAlgoChannelInput inputSource : inputSources) {
                serverAlgoInputChannels.add(inputSource.clone4log());
            }            
        }
        useGroupedOutput = cloneFrom.isUseGroupedOutput();
        logAlways = cloneFrom.isLogAlways();        
    }

    public List<ServerAlgoChannelInput> getServerAlgoInputChannels() {
        return serverAlgoInputChannels;
    }

    public void setServerAlgoInputChannels(List<ServerAlgoChannelInput> serverAlgoInputChannels) {
        this.serverAlgoInputChannels = serverAlgoInputChannels;
    }

    public List<ServerAlgoDestination> getServerAlgoDestinations() {
        return serverAlgoDestinations;
    }

    public void setServerAlgoDestinations(List<ServerAlgoDestination> serverAlgoDestinations) {
        this.serverAlgoDestinations = serverAlgoDestinations;
    }

    public Map<String, AlgoParameterBean> getAlgoBeanParameters() {
        return algoBeanParameters;
    }

    public void setAlgoBeanParameters(Map<String, AlgoParameterBean> algoParameters) {
        this.algoBeanParameters = algoParameters;
    }

    public boolean isUseGroupedOutput() {
        return useGroupedOutput;
    }

    public void setUseGroupedOutput(boolean useGroupedOutput) {
        this.useGroupedOutput = useGroupedOutput;
    }

    public boolean isLogAlways() {
        return logAlways;
    }

    public void setLogAlways(boolean logAlways) {
        this.logAlways = logAlways;
    }

    @Override
    public ServerCommandAlgoParameters clone4log() {
        return new ServerCommandAlgoParameters(this);
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = super.hashCode();
        result = prime * result + ((algoBeanParameters == null) ? 0 : algoBeanParameters.hashCode());
        result = prime * result + (logAlways ? 1231 : 1237);
        result = prime * result + ((serverAlgoDestinations == null) ? 0 : serverAlgoDestinations.hashCode());
        result = prime * result + ((serverAlgoInputChannels == null) ? 0 : serverAlgoInputChannels.hashCode());
        result = prime * result + (useGroupedOutput ? 1231 : 1237);
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (!super.equals(obj))
            return false;
        if (getClass() != obj.getClass())
            return false;
        ServerCommandAlgoParameters other = (ServerCommandAlgoParameters) obj;
        if (algoBeanParameters == null) {
            if (other.algoBeanParameters != null)
                return false;
        }
        else if (!algoBeanParameters.equals(other.algoBeanParameters))
            return false;
        if (logAlways != other.logAlways)
            return false;
        if (serverAlgoDestinations == null) {
            if (other.serverAlgoDestinations != null)
                return false;
        }
        else if (!serverAlgoDestinations.equals(other.serverAlgoDestinations))
            return false;
        if (serverAlgoInputChannels == null) {
            if (other.serverAlgoInputChannels != null)
                return false;
        }
        else if (!serverAlgoInputChannels.equals(other.serverAlgoInputChannels))
            return false;
        if (useGroupedOutput != other.useGroupedOutput)
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "ServerCommandAlgoParameters [serverAlgoInputChannels=" + serverAlgoInputChannels + ", serverAlgoDestinations="
                + serverAlgoDestinations + ", algoBeanParameters=" + algoBeanParameters + ", useGroupedOutput=" + useGroupedOutput
                + ", logAlways=" + logAlways + ", getParameters()=" + getParameters() + ", getExecutionEnvironment()="
                + getExecutionEnvironment() + ", getNotificationPreferences()=" + getNotificationPreferences() + "]";
    }

}
