package com.clcbio.client.thin.model.command.algo.parameter;

import java.util.ArrayList;
import java.util.List;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.clcurl.ClcUrlParameter;

public class AlgoParameterBean implements CommonBeanSerialization {
    private static final long serialVersionUID = 7562462009692487219L;

    private String option;
    private String shortDescription;
    private String longDescription;
    private DefaultBeanParameterValueDefinition valueDefinition;
    private boolean mandatory;
    /*
     * When copying another beans values into this for transport at runtime, the
     * Generic type information is not available
     */
    @SuppressWarnings("unchecked")
    private List values;
    /*
     * Since serialization of Bean Fields of type "Class" makes GWT ignore the
     * Bean (and the debug plugin to crash) this field has to an object.
     */
    private AlgoParameterValueType valueType;

    public AlgoParameterBean() {
        super();
        values = new ArrayList();
    }

    public AlgoParameterBean(String option, String shortDescription, String longDescription,
            DefaultBeanParameterValueDefinition valueDefinition, boolean mandatory, List<? extends Object> values,
            AlgoParameterValueType valueType) {
        super();
        this.option = option;
        this.shortDescription = shortDescription;
        this.longDescription = longDescription;
        this.valueDefinition = valueDefinition;
        this.mandatory = mandatory;
        this.values = values;
        this.valueType = valueType;
    }

    public String getOption() {
        return option;
    }

    public void setOption(String option) {
        this.option = option;
    }

    public String getShortDescription() {
        return shortDescription;
    }

    public void setShortDescription(String shortDescription) {
        this.shortDescription = shortDescription;
    }

    public String getLongDescription() {
        return longDescription;
    }

    public void setLongDescription(String longDescription) {
        this.longDescription = longDescription;
    }

    public DefaultBeanParameterValueDefinition getValueDefinition() {
        return valueDefinition;
    }

    public void setValueDefinition(DefaultBeanParameterValueDefinition valueDefinition) {
        this.valueDefinition = valueDefinition;
    }

    public boolean isMandatory() {
        return mandatory;
    }

    public void setMandatory(boolean mandatory) {
        this.mandatory = mandatory;
    }

    @SuppressWarnings("unchecked")
    public List<? extends Object> getValues() {
        return values;
    }

    public void setValues(List<? extends Object> values) {
        this.values = values;
    }

    public AlgoParameterValueType getValueType() {
        return valueType;
    }

    public void setValueType(AlgoParameterValueType type) {
        this.valueType = type;
    }

    @SuppressWarnings("unchecked")
    public AlgoParameterBean clone4log() {
        List valuesClone;
        valuesClone = new ArrayList();
        if (values != null) {
            for (Object object : values) {
                if (object instanceof ClcUrlParameter) {
                    ClcUrlParameter up = (ClcUrlParameter) object;
                    valuesClone.add(up.clone4log());
                }
                else {
                    // leave presumably primitive types
                    valuesClone.add(object);
                }
            }
        }
        return new AlgoParameterBean(option, shortDescription, longDescription, valueDefinition, mandatory, valuesClone, valueType);
    }

    @Override
    public String toString() {
        return "AlgoParameterBean [longDescription=" + longDescription + ", mandatory=" + mandatory + ", option=" + option
                + ", shortDescription=" + shortDescription + ", valueDefinition=" + valueDefinition + ", valueType=" + valueType
                + ", values=" + values + "]";
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((longDescription == null) ? 0 : longDescription.hashCode());
        result = prime * result + (mandatory ? 1231 : 1237);
        result = prime * result + ((option == null) ? 0 : option.hashCode());
        result = prime * result + ((shortDescription == null) ? 0 : shortDescription.hashCode());
        result = prime * result + ((valueDefinition == null) ? 0 : valueDefinition.hashCode());
        result = prime * result + ((valueType == null) ? 0 : valueType.hashCode());
        result = prime * result + ((values == null) ? 0 : values.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        AlgoParameterBean other = (AlgoParameterBean) obj;
        if (longDescription == null) {
            if (other.longDescription != null)
                return false;
        }
        else if (!longDescription.equals(other.longDescription))
            return false;
        if (mandatory != other.mandatory)
            return false;
        if (option == null) {
            if (other.option != null)
                return false;
        }
        else if (!option.equals(other.option))
            return false;
        if (shortDescription == null) {
            if (other.shortDescription != null)
                return false;
        }
        else if (!shortDescription.equals(other.shortDescription))
            return false;
        if (valueDefinition == null) {
            if (other.valueDefinition != null)
                return false;
        }
        else if (!valueDefinition.equals(other.valueDefinition))
            return false;
        if (valueType == null) {
            if (other.valueType != null)
                return false;
        }
        else if (!valueType.equals(other.valueType))
            return false;
        if (values == null) {
            if (other.values != null)
                return false;
        }
        else if (!values.equals(other.values))
            return false;
        return true;
    }

}
