package com.clcbio.client.thin.model.command.algo.parameter.type;

import com.clcbio.client.thin.model.command.algo.parameter.AlgoParameterValueType;

public class ValueTypeInteger extends AlgoParameterValueType {
    private static final long serialVersionUID = -3169828138762541849L;
    private Integer min;
    private Integer max;
    
    /**
     * Calling this passes {@link Integer}'s MIN_VALUE and MAX_VALUE as min and max parameters to
     * {@link #ValueTypeInteger(Integer, Integer)}
     */
    public ValueTypeInteger() {
        this(Integer.MIN_VALUE, Integer.MAX_VALUE);
    }
    
    /**
     * Passing null as min parameter will be converted to MIN_VALUE and max as null to MAX_VALUE
     * 
     * @param min
     * @param max
     */
    public ValueTypeInteger(Integer min, Integer max) {
        super(Integer.class.getName());
        if (min == null) {
            this.min = Integer.MIN_VALUE;
        }
        else {
            this.min = min;
        }
        if (max == null) {
            this.max = Integer.MAX_VALUE;
        }
        else {
            this.max = max;
        }
    }
    
    public Integer getMin() {
        return min;
    }
    
    public void setMin(Integer min) {
        this.min = min;
    }
    
    public Integer getMax() {
        return max;
    }
    
    public void setMax(Integer max) {
        this.max = max;
    }
    
}
