package com.clcbio.client.thin.model.command.batch;

import java.util.ArrayList;
import java.util.List;

import com.clcbio.client.thin.model.command.ServerCommandParameters;
import com.clcbio.client.thin.model.command.ServerCommandReference;

public class ServerBatchCommandParameters extends ServerCommandParameters {
    
    private static final long serialVersionUID = 9050716845362141904L;
    private List<ServerCommandReference> commandRefs;
    private ServerCommandReference postProcessCommandRef;
    private List<String> validPostProcessTypes;
    
    @Override
    public ServerCommandParameters clone4log() {
        ServerBatchCommandParameters clone = new ServerBatchCommandParameters(super.clone4log());
        if (postProcessCommandRef != null) {
            clone.setPostProcessCommandRef(postProcessCommandRef.clone4log());
        }
        if (commandRefs != null) {
            ArrayList<ServerCommandReference> clones = new ArrayList<ServerCommandReference>();
            for (ServerCommandReference commandRef : commandRefs) {
                if (commandRef != null) {
                    clones.add(commandRef.clone4log());
                }
            }
            clone.setCommandRefs(clones);
        }
        
        if (validPostProcessTypes != null) {
            ArrayList<String> clones = new ArrayList<String>();
            for (String c : validPostProcessTypes) {
                if (c != null) {
                    clones.add(c);
                }
            }
            clone.setValidPostProcessTypes(clones);
        }
        return clone;
    }
    
    public ServerBatchCommandParameters() {
        super();
        init();
    }
    
    public ServerBatchCommandParameters(ServerCommandParameters commandParameters) {
        super(commandParameters);
        init();
    }
    
    private void init() {
        commandRefs = new ArrayList<ServerCommandReference>();
        validPostProcessTypes = new ArrayList<String>();
    }
    
    @Override
    public String toString() {
        return "ServerBatchCommandParameters [commandRefs=" + commandRefs + ", postProcessCommandRef=" + postProcessCommandRef
                + ", validPostProcessTypes=" + validPostProcessTypes + "]";
    }
    
    public List<ServerCommandReference> getCommandRefs() {
        return commandRefs;
    }
    
    public void setCommandRefs(List<ServerCommandReference> commandRefs) {
        this.commandRefs = commandRefs;
    }
    
    public List<String> getValidPostProcessTypes() {
        return validPostProcessTypes;
    }
    
    public void setValidPostProcessTypes(List<String> validPostProcessTypes) {
        this.validPostProcessTypes = validPostProcessTypes;
    }
    
    public ServerCommandReference getPostProcessCommandRef() {
        return postProcessCommandRef;
    }
    
    public void setPostProcessCommandRef(ServerCommandReference postProcessCommandRef) {
        this.postProcessCommandRef = postProcessCommandRef;
    }
}
