package com.clcbio.client.thin.model.command.clexe;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.clcbio.client.thin.model.admin.configuration.subsystem.safefiles.SafeFileDirectory;
import com.clcbio.client.thin.model.command.ServerCommandParameters;
import com.clcbio.client.thin.model.command.clexe.types.TypeBinaryObject;
import com.clcbio.client.thin.model.command.clexe.types.TypeBooleanCompound;
import com.clcbio.client.thin.model.command.clexe.types.TypeImportCommandInput;
import com.clcbio.client.thin.model.command.clexe.types.UserClArg;
import com.google.gwt.user.client.rpc.IsSerializable;

public class CommandLineExecuterParameters extends ServerCommandParameters implements IsSerializable {
    private static final long serialVersionUID = 1704443676100215819L;
    private String command;
    private TypeImportCommandInput standardOutImporter;
    private TypeImportCommandInput standardErrorImporter;
    private boolean standardErrorCausesException;
    private boolean runtimeMasterCommand;
    public String USER_PARAM_START_TAG = "{";
    public String USER_PARAM_END_TAG = "}";
    private List<UserClArg> userArguments;
    private Map<String, String> environmentVariables;
    private String postProcessAlgoCommandId;
    private Map<String, String> userArgIdToPostProcessAlgoParamIdMap;
    private List<UserClArg> userArgumentsForPostProcessingOnly;
    private String mandatoryPostTerminationDeletableWorkDir;
    private SafeFileDirectory userSetSharedWorkDir;
    private int userParameterWindowSize;
    
    public List<UserClArg> getUserArguments() {
        return userArguments;
    }

    public void setUserArguments(List<UserClArg> userArguments) {
        this.userArguments = userArguments;
    }

    public CommandLineExecuterParameters() {
        super();
        init();
    }

    public CommandLineExecuterParameters(ServerCommandParameters commandParameters) {
        super(commandParameters);
        init();
    }

    private void init() {
        command = "";
        userSetSharedWorkDir = null;
        mandatoryPostTerminationDeletableWorkDir = "";
        standardOutImporter = new TypeImportCommandInput();
        standardOutImporter.setId("standardOutImporter");
        standardErrorImporter = new TypeImportCommandInput();
        standardErrorImporter.setId("standardErrorImporter");

        userArguments = new ArrayList<UserClArg>();
        userArgumentsForPostProcessingOnly = new ArrayList<UserClArg>();
        environmentVariables = new HashMap<String, String>();
        postProcessAlgoCommandId = "";
        userArgIdToPostProcessAlgoParamIdMap = new HashMap<String, String>();
        standardErrorCausesException = true;
        runtimeMasterCommand = false;
        userParameterWindowSize = 4;
    }

    public int getUserParameterWindowSize() {
        return userParameterWindowSize;
    }

    public void setUserParameterWindowSize(int userParameterWindowSize) {
        this.userParameterWindowSize = userParameterWindowSize;
    }

    @Override
    public String toString() {
        return "CommandLineExecuterParameters [command=" + command + ", standardOutImporter=" + standardOutImporter
                + ", standardErrorImporter=" + standardErrorImporter + ", standardErrorCausesException="
                + standardErrorCausesException + ", runtimeMasterCommand=" + runtimeMasterCommand + ", USER_PARAM_START_TAG="
                + USER_PARAM_START_TAG + ", USER_PARAM_END_TAG=" + USER_PARAM_END_TAG + ", userArguments=" + userArguments
                + ", environmentVariables=" + environmentVariables + ", postProcessAlgoCommandId=" + postProcessAlgoCommandId
                + ", userArgIdToPostProcessAlgoParamIdMap=" + userArgIdToPostProcessAlgoParamIdMap
                + ", userArgumentsForPostProcessingOnly=" + userArgumentsForPostProcessingOnly
                + ", mandatoryPostTerminationDeletableWorkDir=" + mandatoryPostTerminationDeletableWorkDir + ", userSetSharedWorkDir="
                + userSetSharedWorkDir + ", userParameterWindowSize=" + userParameterWindowSize + "]";
    }

    public String getCommand() {
        return command;
    }

    public void setCommand(String command) {
        this.command = command;
    }

    public String getMandatoryPostTerminationDeletableWorkDir() {
        return mandatoryPostTerminationDeletableWorkDir;
    }

    public void setMandatoryPostTerminationDeletableWorkDir(String postProcessDeletableWorkDir) {
        this.mandatoryPostTerminationDeletableWorkDir = postProcessDeletableWorkDir;
    }

    public TypeImportCommandInput getStandardOutImporter() {
        return standardOutImporter;
    }

    public void setStandardOutImporter(TypeImportCommandInput standardOutImporter) {
        this.standardOutImporter = standardOutImporter;
    }

    public Map<String, String> getEnvironmentVariables() {
        return environmentVariables;
    }

    public void setEnvironmentVariables(Map<String, String> environmentVariables) {
        this.environmentVariables = environmentVariables;
    }

    public String getPostProcessAlgoCommandId() {
        return postProcessAlgoCommandId;
    }

    public void setPostProcessAlgoCommandId(String postProcessAlgoCommandId) {
        this.postProcessAlgoCommandId = postProcessAlgoCommandId;
    }

    public Map<String, String> getUserArgIdToPostProcessAlgoParamIdMap() {
        return userArgIdToPostProcessAlgoParamIdMap;
    }

    public void setUserArgIdToPostProcessAlgoParamIdMap(Map<String, String> userArgIdToPostProcessAlgoParamIdMap) {
        this.userArgIdToPostProcessAlgoParamIdMap = userArgIdToPostProcessAlgoParamIdMap;
    }

    public List<UserClArg> getUserArgumentsForPostProcessingOnly() {
        return userArgumentsForPostProcessingOnly;
    }

    public void setUserArgumentsForPostProcessingOnly(List<UserClArg> userArgumentsForPostProcessingOnly) {
        this.userArgumentsForPostProcessingOnly = userArgumentsForPostProcessingOnly;
    }

    public TypeImportCommandInput getStandardErrorImporter() {
        return standardErrorImporter;
    }

    public void setStandardErrorImporter(TypeImportCommandInput standardErrorImporter) {
        this.standardErrorImporter = standardErrorImporter;
    }

    public boolean isStandardErrorCausesException() {
        return standardErrorCausesException;
    }

    public void setStandardErrorCausesException(boolean standardErrorCausesException) {
        this.standardErrorCausesException = standardErrorCausesException;
    }

    public boolean isRuntimeMasterCommand() {
        return runtimeMasterCommand;
    }

    public void setRuntimeMasterCommand(boolean preferExecutionAsMasterCommand) {
        this.runtimeMasterCommand = preferExecutionAsMasterCommand;
    }

    public SafeFileDirectory getUserSetSharedWorkDir() {
        return userSetSharedWorkDir;
    }

    public void setUserSetSharedWorkDir(SafeFileDirectory userSetSharedWorkDir) {
        this.userSetSharedWorkDir = userSetSharedWorkDir;
    }

    @Override
    public CommandLineExecuterParameters clone4log() {
        CommandLineExecuterParameters clone = new CommandLineExecuterParameters(super.clone4log());
        clone.setCommand(getCommand());
        clone.setUserSetSharedWorkDir(getUserSetSharedWorkDir());
        clone.setStandardOutImporter(getStandardOutImporter());
        clone.setUserArguments(filterOutBinaries(getUserArguments()));
        clone.setUserArgumentsForPostProcessingOnly(filterOutBinaries(getUserArgumentsForPostProcessingOnly()));
        clone.setEnvironmentVariables(new HashMap<String, String>(getEnvironmentVariables()));
        clone.setPostProcessAlgoCommandId(getPostProcessAlgoCommandId());
        clone.setUserArgIdToPostProcessAlgoParamIdMap(new HashMap<String, String>(getUserArgIdToPostProcessAlgoParamIdMap()));
        clone.setStandardErrorImporter(getStandardErrorImporter());
        clone.setStandardErrorCausesException(isStandardErrorCausesException());
        clone.setRuntimeMasterCommand(isRuntimeMasterCommand());
        clone.setMandatoryPostTerminationDeletableWorkDir(getMandatoryPostTerminationDeletableWorkDir());
        return clone;
    }

    private ArrayList<UserClArg> filterOutBinaries(List<UserClArg> userArgs) {
        ArrayList<UserClArg> thins = new ArrayList<UserClArg>();
        for (UserClArg userClArg : userArgs) {
            thins.add(filterOutBinary(userClArg));
        }
        return thins;
    }

    private UserClArg filterOutBinary(UserClArg userClArg) {
        if (userClArg instanceof TypeBooleanCompound) {
            TypeBooleanCompound bc = (TypeBooleanCompound) userClArg;
            TypeBooleanCompound clone = new TypeBooleanCompound();
            clone.setValue(bc.getValue());
            clone.setId(bc.getId());
            clone.setEnabled(bc.isEnabled());
            clone.setDisplayName(bc.getDisplayName());
            clone.setArgumentType(bc.getArgumentType());
            clone.setCompoundUserArg(filterOutBinary(bc.getCompoundUserArg()));
            return clone;
        }
        else if (userClArg instanceof TypeBinaryObject) {
            TypeBinaryObject tbo = (TypeBinaryObject) userClArg;
            return tbo.clone4log();
        }
        else {
            return userClArg;
        }
    }

    public Set<String> parseForUserParams(String text) {
        Set<String> valuesInBetween = new HashSet<String>();
        int startIndex = 0;
        int endIndex = 0;
        while (text.indexOf(USER_PARAM_START_TAG, endIndex) > -1) {
            startIndex = text.indexOf(USER_PARAM_START_TAG, endIndex) + USER_PARAM_START_TAG.length();
            endIndex = text.indexOf(USER_PARAM_END_TAG, startIndex);
            if (endIndex == -1) {
                break;
            }
            valuesInBetween.add(text.substring(startIndex, endIndex));
        }
        return valuesInBetween;
    }

    @Override
    public boolean equals(Object obj) {
        // rely on tostring...
        return this.toString().equals(obj.toString());
    }

}
