package com.clcbio.client.thin.model.command.direct;

import java.util.ArrayList;
import java.util.List;

import com.clcbio.client.thin.model.CommonBeanSerialization;
import com.clcbio.client.thin.model.command.ServerCommandParameters;
import com.clcbio.client.thin.model.serialization.SerializedBeanJSON;
import com.clcbio.client.thin.model.serialization.SerializedBeanXML;

public class DirectCommandParameters extends ServerCommandParameters implements CommonBeanSerialization {
    private static final long serialVersionUID = 91290246795477206L;
    private String implementingClassName;
    private String methodName;
    private List<SerializedBeanXML> methodArguments;
    private List<DirectCommandParametersAttribute> methodAttributes;
    /*
     * Should have been class, not instance, but GWT can serialize classes
     */
    private SerializedBeanXML preferredReturnSerializationPolizy;
    
    public DirectCommandParameters() {
        super();
        methodArguments = new ArrayList<SerializedBeanXML>();
        methodName = "";
        implementingClassName = "";
        preferredReturnSerializationPolizy = new SerializedBeanJSON();
        methodAttributes = new ArrayList<DirectCommandParametersAttribute>();
    }

    public DirectCommandParameters(DirectCommandParameters commandParameters) {
        super(commandParameters);
        methodArguments = new ArrayList<SerializedBeanXML>();
        List<SerializedBeanXML> args = commandParameters.getMethodArguments();
        for (SerializedBeanXML transportParameterJavaBean : args) {
            methodArguments.add(transportParameterJavaBean.clone4log());
        }
        methodAttributes = new ArrayList<DirectCommandParametersAttribute>();
        for(DirectCommandParametersAttribute attr: commandParameters.getMethodAttributes()) {
            methodAttributes.add(attr.clone4log());
        }
        methodName = commandParameters.getMethodName();
        implementingClassName = commandParameters.getImplementingClassName();
        preferredReturnSerializationPolizy = commandParameters.getPreferredReturnSerializationPolizy().clone4log();
        
    }

    public String getImplementingClassName() {
        return implementingClassName;
    }
    public void setImplementingClassName(String className) {
        this.implementingClassName = className;
    }
    public String getMethodName() {
        return methodName;
    }
    public void setMethodName(String methodName) {
        this.methodName = methodName;
    }

    public List<SerializedBeanXML> getMethodArguments() {
        return methodArguments;
    }

    public void setMethodArguments(List<SerializedBeanXML> methodArguments) {
        this.methodArguments = methodArguments;
    }

    public SerializedBeanXML getPreferredReturnSerializationPolizy() {
        return preferredReturnSerializationPolizy;
    }

    public void setPreferredReturnSerializationPolizy(SerializedBeanXML preferredReturnSerializationPolizy) {
        this.preferredReturnSerializationPolizy = preferredReturnSerializationPolizy;
    }

    public List<DirectCommandParametersAttribute> getMethodAttributes() {
        return methodAttributes;
    }
    
    public void setMethodAttributes(List<DirectCommandParametersAttribute> attrs) {
        methodAttributes = attrs;
    }
    
    @Override
    public DirectCommandParameters clone4log() {
        return new DirectCommandParameters(this);
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((implementingClassName == null) ? 0 : implementingClassName.hashCode());
        result = prime * result + ((methodArguments == null) ? 0 : methodArguments.hashCode());
        result = prime * result + ((methodName == null) ? 0 : methodName.hashCode());
        result = prime * result + ((preferredReturnSerializationPolizy == null) ? 0 : preferredReturnSerializationPolizy.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        DirectCommandParameters other = (DirectCommandParameters) obj;
        if (implementingClassName == null) {
            if (other.implementingClassName != null)
                return false;
        }
        else if (!implementingClassName.equals(other.implementingClassName))
            return false;
        if (methodArguments == null) {
            if (other.methodArguments != null)
                return false;
        }
        else if (!methodArguments.equals(other.methodArguments))
            return false;
        if (methodName == null) {
            if (other.methodName != null)
                return false;
        }
        else if (!methodName.equals(other.methodName))
            return false;
        if (preferredReturnSerializationPolizy == null) {
            if (other.preferredReturnSerializationPolizy != null)
                return false;
        }
        else if (!preferredReturnSerializationPolizy.equals(other.preferredReturnSerializationPolizy))
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "DirectCommandParameters [implementingClassName=" + implementingClassName + ", methodName=" + methodName
                + ", methodArguments=" + methodArguments + ", methodAttributes=" + methodAttributes
                + ", preferredReturnSerializationPolizy=" + preferredReturnSerializationPolizy + "]";
    }
    
}
