package com.clcbio.client.thin.model.command.plugin;

import com.clcbio.client.thin.model.ThinBinaryData;
import com.clcbio.client.thin.model.command.CommandExecutionScope;
import com.clcbio.client.thin.model.command.ServerCommandParameters;
import com.google.gwt.user.client.rpc.IsSerializable;

public class ServerPluginManagementParameters extends ServerCommandParameters implements IsSerializable, CommandExecutionScope {

    private static final long serialVersionUID = 1L;
    private ThinBinaryData sOAPBinaryDataCpaFileToInstall;
    private Operation operation;
    private String pluginToUnInstallId;
    private ClusterExecutionScope clusterExecutionScope;
    private String dedicatedSlaveNodeId;

    public enum Operation implements IsSerializable {
        INSTALL_PLUGIN, UNINSTALL_PLUGIN, RELOAD_PLUGINS, NO_OPERATION
    }

    public ServerPluginManagementParameters() {
        super();
        init();
    }

    public ServerPluginManagementParameters(ServerCommandParameters commandParameters) {
        super(commandParameters);
        init();
    }

    private void init() {
        sOAPBinaryDataCpaFileToInstall = new ThinBinaryData();
        operation = Operation.NO_OPERATION;
        pluginToUnInstallId = "";
        clusterExecutionScope = ClusterExecutionScope.EXECUTE_MASTER;
        dedicatedSlaveNodeId = "";
    }

    @Override
    public String toString() {
        return super.toString() + "," + "pluginFile=" + sOAPBinaryDataCpaFileToInstall + ", Operation=" + getOperation()
                + ",PluginToUnInstallId=" + getPluginToUnInstallId() + ",clusterExecutionScope=" + getClusterExecutionScope()
                + ",dedicatedSlaveNode=" + getDedicatedSlaveNodeId();
    }

    @Override
    public ServerPluginManagementParameters clone4log() {
        ServerPluginManagementParameters clone = new ServerPluginManagementParameters(super.clone4log());
        // do not clone the file itself!
        clone.setCpaFileToInstall(getCpaFileToInstall().clone4log());
        clone.setOperation(getOperation());
        clone.setPluginToUnInstallId(getPluginToUnInstallId());
        return clone;
    }

    public String getPluginToUnInstallId() {
        return pluginToUnInstallId;
    }

    public void setPluginToUnInstallId(String pluginToUnInstallId) {
        this.pluginToUnInstallId = pluginToUnInstallId;
    }

    /**
     * Since GWT cannot serialize SOAPBinaryData and this model has to be used
     * in both SOAP and GWT, we will have to go for Object
     * 
     * @return object of type SOAPBinaryData
     */
    public ThinBinaryData getCpaFileToInstall() {
        return sOAPBinaryDataCpaFileToInstall;
    }

    /**
     * Since GWT cannot serialize SOAPBinaryData and this model has to be used
     * in both SOAP and GWT, we will have to go for Object
     * 
     * @param sOAPBinaryDataCpaFileToInstall
     */
    public void setCpaFileToInstall(ThinBinaryData sOAPBinaryDataCpaFileToInstall) {
        this.sOAPBinaryDataCpaFileToInstall = sOAPBinaryDataCpaFileToInstall;
    }

    public Operation getOperation() {
        return operation;
    }

    public void setOperation(Operation operation) {
        this.operation = operation;
    }

    public ClusterExecutionScope getClusterExecutionScope() {
        return clusterExecutionScope;
    }

    public void setClusterExecutionScope(ClusterExecutionScope clusterExecutionScope) {
        this.clusterExecutionScope = clusterExecutionScope;
    }

    public String getDedicatedSlaveNodeId() {
        return dedicatedSlaveNodeId;
    }

    public void setDedicatedSlaveNodeId(String dedicatedSlaveNodeId) {
        this.dedicatedSlaveNodeId = dedicatedSlaveNodeId;
    }

}
