package com.clcbio.client.thin.model.command.workflow;

import java.util.ArrayList;
import java.util.List;

import com.clcbio.api.clc.workflows.bean.WorkflowBean;
import com.clcbio.client.thin.model.clcurl.ClcUrlParameter;
import com.clcbio.client.thin.model.command.ServerCommandParameters;
import com.google.gwt.user.client.rpc.IsSerializable;

public class WorkflowCommandParameters extends ServerCommandParameters implements IsSerializable {
    private static final long serialVersionUID = -7547341904515349440L;
    private WorkflowBean workflowBean;
    private List<ClcUrlParameter> serverWorkflowSource;
    private ClcUrlParameter serverWorkflowDestination;

    public WorkflowCommandParameters() {
        super();
        workflowBean = new WorkflowBean();
        serverWorkflowSource = new ArrayList<ClcUrlParameter>();
        serverWorkflowDestination = new ClcUrlParameter();
    }

    public WorkflowCommandParameters(WorkflowCommandParameters cloneSource) {
        super(cloneSource);
        serverWorkflowSource = new ArrayList<ClcUrlParameter>();
        workflowBean = new WorkflowBean(cloneSource.getWorkflowBean());
        List<ClcUrlParameter> sourceSources = cloneSource.getServerWorkflowSource();
        if(sourceSources != null){
            for (ClcUrlParameter clcUrlParameter : sourceSources) {
                serverWorkflowSource.add(clcUrlParameter.clone4log());
            }            
        }
        ClcUrlParameter destSource = cloneSource.getServerWorkflowDestination();
        if(destSource != null){
            serverWorkflowDestination = destSource.clone4log();
            }
        else{
            serverWorkflowDestination = new ClcUrlParameter();
        }
    }

    public WorkflowBean getWorkflowBean() {
        return workflowBean;
    }

    public void setWorkflowBean(WorkflowBean workflowBean) {
        this.workflowBean = workflowBean;
    }

    public List<ClcUrlParameter> getServerWorkflowSource() {
        return serverWorkflowSource;
    }

    public void setServerWorkflowSource(List<ClcUrlParameter> serverWorkflowSource) {
        this.serverWorkflowSource = serverWorkflowSource;
    }

    public ClcUrlParameter getServerWorkflowDestination() {
        return serverWorkflowDestination;
    }

    public void setServerWorkflowDestination(ClcUrlParameter serverWorkflowDestination) {
        this.serverWorkflowDestination = serverWorkflowDestination;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = super.hashCode();
        result = prime * result + ((serverWorkflowDestination == null) ? 0 : serverWorkflowDestination.hashCode());
        result = prime * result + ((serverWorkflowSource == null) ? 0 : serverWorkflowSource.hashCode());
        result = prime * result + ((workflowBean == null) ? 0 : workflowBean.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (!super.equals(obj))
            return false;
        if (getClass() != obj.getClass())
            return false;
        WorkflowCommandParameters other = (WorkflowCommandParameters) obj;
        if (serverWorkflowDestination == null) {
            if (other.serverWorkflowDestination != null)
                return false;
        }
        else if (!serverWorkflowDestination.equals(other.serverWorkflowDestination))
            return false;
        if (serverWorkflowSource == null) {
            if (other.serverWorkflowSource != null)
                return false;
        }
        else if (!serverWorkflowSource.equals(other.serverWorkflowSource))
            return false;
        if (workflowBean == null) {
            if (other.workflowBean != null)
                return false;
        }
        else if (!workflowBean.equals(other.workflowBean))
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "WorkflowCommandParameters [workflowBean=" + workflowBean + ", serverWorkflowSource=" + serverWorkflowSource
                + ", serverWorkflowDestination=" + serverWorkflowDestination + ", getExecutionEnvironment()="
                + getExecutionEnvironment() + ", getNotificationPreferences()=" + getNotificationPreferences() + "]";
    }

    @Override
    public ServerCommandParameters clone4log() {
        return new WorkflowCommandParameters(this);
    }

}
