package com.clcbio.client.thin.model.processes;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import com.clcbio.client.thin.model.exceptions.ThinException;
import com.google.gwt.user.client.rpc.IsSerializable;

/**
 * A reflection of a Server Process based upon selected values, readable by a
 * remote Observer (thus not containing any heavy non-trivial Objects)
 * 
 */
public class ClcProcessReflection implements IsSerializable {
    private String processID;
    private int progress;
    private String statusDescription;
    private String description;
    private long jobStartTime;
    private long creationTime;
    private boolean suspendable;
    private boolean stoppable;
    private boolean done;
    private boolean suspended;
    private String username;
    private String lastPostedMessage;
    private List<ThinException> processExceptions;
    private String executingServerDescription;
    private boolean isRequeueable;
    private Set<String> childProcessIds;
    private String commandClassification;

    public ClcProcessReflection() {
        super();
        this.processID = "";
        this.progress = -1;
        this.statusDescription = "";
        this.description = "";
        this.jobStartTime = 0;
        this.creationTime = 0;
        this.suspendable = false;
        this.stoppable = false;
        this.done = false;
        this.suspended = false;
        this.username = "";
        this.lastPostedMessage = "";
        this.processExceptions = new ArrayList<ThinException>();
        this.executingServerDescription = "";
        this.isRequeueable = false;
        this.childProcessIds = new HashSet<String>();
        this.commandClassification = "";
    }

    public ClcProcessReflection(ClcProcessReflection cloneFrom) {
        super();
        this.processID = cloneFrom.getProcessID();
        this.progress = cloneFrom.getProgress();
        this.statusDescription = cloneFrom.getStatusDescription();
        this.description = cloneFrom.getDescription();
        this.jobStartTime = cloneFrom.getJobStartTime();
        this.creationTime = cloneFrom.getCreationTime();
        this.suspendable = cloneFrom.isSuspendable();
        this.stoppable = cloneFrom.isStoppable();
        this.done = cloneFrom.isDone();
        this.suspended = cloneFrom.isSuspended();
        this.username = cloneFrom.getUsername();
        this.lastPostedMessage = cloneFrom.getLastPostedMessage();
        List<ThinException> cloneXs = cloneFrom.getProcessExceptions();
        if(cloneXs == null){
            processExceptions = null;
        }
        else{
            this.processExceptions = new ArrayList<ThinException>();
            processExceptions.addAll(cloneXs);            
        }
        this.executingServerDescription = cloneFrom.getExecutingServerDescription();
        this.isRequeueable = cloneFrom.isRequeueable();
        Set<String> cloneIDs = cloneFrom.getChildProcessIds();
        if(cloneIDs == null){
            this.childProcessIds = null;            
        }
        else{
            this.childProcessIds = new HashSet<String>();
            childProcessIds.addAll(cloneIDs);
        }
        this.commandClassification = cloneFrom.getCommandClassification();
    }

    /**
     * Get the current progress (from 0 to 100).
     * 
     * @return the current progress
     */
    public int getProgress() {
        return progress;
    }

    /**
     * @return the description
     */
    public String getDescription() {
        return description;
    }

    /**
     * @param description
     *            the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }

    public void setProgress(int progress) {
        this.progress = progress;
    }

    public void setStatusDescription(String status) {
        statusDescription = status;
    }

    public String getStatusDescription() {
        return statusDescription;
    }

    /**
     * @return the jobStartTime
     */
    public long getJobStartTime() {
        return jobStartTime;
    }

    /**
     * @param jobStartTime
     *            the jobStartTime to set
     */
    public void setJobStartTime(long jobStartTime) {
        this.jobStartTime = jobStartTime;
    }

    public String getProcessID() {
        return processID;
    }

    public void setProcessID(String processID) {
        this.processID = processID;
    }

    public boolean isSuspendable() {
        return suspendable;
    }

    public void setSuspendable(boolean suspendable) {
        this.suspendable = suspendable;
    }

    public boolean isStoppable() {
        return stoppable;
    }

    public void setStoppable(boolean stoppable) {
        this.stoppable = stoppable;
    }

    public boolean isDone() {
        return done;
    }

    public void setDone(boolean done) {
        this.done = done;
    }

    public boolean isSuspended() {
        return suspended;
    }

    public void setSuspended(boolean suspended) {
        this.suspended = suspended;
    }

    public List<ThinException> getProcessExceptions() {
        return processExceptions;
    }

    public void setProcessExceptions(List<ThinException> processExceptions) {
        this.processExceptions = processExceptions;
    }

    public long getCreationTime() {
        return creationTime;
    }

    public void setCreationTime(long creationTime) {
        this.creationTime = creationTime;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

    public String getLastPostedMessage() {
        return lastPostedMessage;
    }

    public void setLastPostedMessage(String lastPostedMessage) {
        this.lastPostedMessage = lastPostedMessage;
    }

    public String getExecutingServerDescription() {
        return executingServerDescription;
    }

    public void setExecutingServerDescription(String executingServerDescription) {
        this.executingServerDescription = executingServerDescription;
    }

    public boolean isRequeueable() {
        return isRequeueable;
    }

    public void setRequeueable(boolean isRequeueable) {
        this.isRequeueable = isRequeueable;
    }

    public Set<String> getChildProcessIds() {
        return childProcessIds;
    }

    public void setChildProcessIds(Set<String> childProcessIds) {
        this.childProcessIds = childProcessIds;
    }

    public void setCommandClassification(String commandClassification) {
        this.commandClassification = commandClassification;
    }

    public String getCommandClassification() {
        return commandClassification;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((childProcessIds == null) ? 0 : childProcessIds.hashCode());
        result = prime * result + ((commandClassification == null) ? 0 : commandClassification.hashCode());
        result = prime * result + (int) (creationTime ^ (creationTime >>> 32));
        result = prime * result + ((description == null) ? 0 : description.hashCode());
        result = prime * result + (done ? 1231 : 1237);
        result = prime * result + ((executingServerDescription == null) ? 0 : executingServerDescription.hashCode());
        result = prime * result + (isRequeueable ? 1231 : 1237);
        result = prime * result + (int) (jobStartTime ^ (jobStartTime >>> 32));
        result = prime * result + ((lastPostedMessage == null) ? 0 : lastPostedMessage.hashCode());
        result = prime * result + ((processExceptions == null) ? 0 : processExceptions.hashCode());
        result = prime * result + ((processID == null) ? 0 : processID.hashCode());
        result = prime * result + progress;
        result = prime * result + ((statusDescription == null) ? 0 : statusDescription.hashCode());
        result = prime * result + (stoppable ? 1231 : 1237);
        result = prime * result + (suspendable ? 1231 : 1237);
        result = prime * result + (suspended ? 1231 : 1237);
        result = prime * result + ((username == null) ? 0 : username.hashCode());
        return result;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        ClcProcessReflection other = (ClcProcessReflection) obj;
        if (childProcessIds == null) {
            if (other.childProcessIds != null)
                return false;
        }
        else if (!childProcessIds.equals(other.childProcessIds))
            return false;
        if (commandClassification == null) {
            if (other.commandClassification != null)
                return false;
        }
        else if (!commandClassification.equals(other.commandClassification))
            return false;
        if (creationTime != other.creationTime)
            return false;
        if (description == null) {
            if (other.description != null)
                return false;
        }
        else if (!description.equals(other.description))
            return false;
        if (done != other.done)
            return false;
        if (executingServerDescription == null) {
            if (other.executingServerDescription != null)
                return false;
        }
        else if (!executingServerDescription.equals(other.executingServerDescription))
            return false;
        if (isRequeueable != other.isRequeueable)
            return false;
        if (jobStartTime != other.jobStartTime)
            return false;
        if (lastPostedMessage == null) {
            if (other.lastPostedMessage != null)
                return false;
        }
        else if (!lastPostedMessage.equals(other.lastPostedMessage))
            return false;
        if (processExceptions == null) {
            if (other.processExceptions != null)
                return false;
        }
        else if (!processExceptions.equals(other.processExceptions))
            return false;
        if (processID == null) {
            if (other.processID != null)
                return false;
        }
        else if (!processID.equals(other.processID))
            return false;
        if (progress != other.progress)
            return false;
        if (statusDescription == null) {
            if (other.statusDescription != null)
                return false;
        }
        else if (!statusDescription.equals(other.statusDescription))
            return false;
        if (stoppable != other.stoppable)
            return false;
        if (suspendable != other.suspendable)
            return false;
        if (suspended != other.suspended)
            return false;
        if (username == null) {
            if (other.username != null)
                return false;
        }
        else if (!username.equals(other.username))
            return false;
        return true;
    }

    @Override
    public String toString() {
        return "ClcProcessReflection [processID=" + processID + ", progress=" + progress + ", statusDescription=" + statusDescription
                + ", description=" + description + ", jobStartTime=" + jobStartTime + ", creationTime=" + creationTime
                + ", suspendable=" + suspendable + ", stoppable=" + stoppable + ", done=" + done + ", suspended=" + suspended
                + ", username=" + username + ", lastPostedMessage=" + lastPostedMessage + ", processExceptions=" + processExceptions
                + ", executingServerDescription=" + executingServerDescription + ", isRequeueable=" + isRequeueable
                + ", childProcessIds=" + childProcessIds + ", commandClassification=" + commandClassification + "]";
    }

}
