package com.clcbio.client.thin.model.qualification;

import com.clcbio.client.thin.model.CommonBeanSerialization;
/***                                                                                                
* <pre>                                                                                             
*           +---------------------------------------+                                               
*           | Qualifies Execution                   |                                               
*           | (Source and destination available) (*)|                                               
*           +---------------------------------------+                  ^                            
*                              ^                                       |                            
*                              |                                       |                            
*           +---------------------------------------+                  |                            
*           | Qualifies Source and Destination      |                  |                            
*           | (Source and destination stated)       |                  |                            
*           +---------------------------------------+                  |                            
*                              ^                                       |                            
*                              |                                       |                            
*           +---------------------------------------+                  |                            
*           | Qualifies Reference Parameters        |                  |                            
*           | (Reference parameters available) (*)  |                  |                            
*           +---------------------------------------+                  |                            
*                              ^                                       |                            
*                              |                                       |                            
*           +---------------------------------------+                  |                            
*           | Qualifies Parameters (Mandatory       |                Execution                      
*           | parameters stated)                    |                Qualification                  
*           +---------------------------------------+                  |                            
*                              ^                                       |                            
*                              |                                       |                            
*           +---------------------------------------+                  |                            
*           | Qualifies Commands                    |                  |                            
*           | (Referred Commands available) (*)     |                  |                            
*           +---------------------------------------+                  |                            
*                              ^                                       |                            
*                              |                                       |                            
*           +---------------------------------------+                  |                            
*           | Qualifies Model                       |                  |                            
*           | (Description Model conformity)        |                  |                            
*           +---------------------------------------+                  |                            
*                             ^                                        |                            
*                             |                                        |                            
*           +---------------------------------------+                  |                            
*           | Disqualified                          |                                               
*           +---------------------------------------+                                               
*                                                                                                   
*                                                                                                   
*           (*) availability                                                                        
*           vary by context                                                                         
*                                                                                                   
*                                                                                                   
*</pre>                                                                                             
*                                                                                                   
*/                                                                                                
                                                                                                 
public enum QualificationClassification implements CommonBeanSerialization {
    LEVEL_00_DISQUALIFIED("Does not conform to description model or supported versions hereof"),
    LEVEL_01_QUALIFIES_MODEL("Description Model conformity of server execuable"),
    LEVEL_02_QUALIFIES_COMMANDS("Referred Server commands are availble in context"),
    LEVEL_03_QUALIFIES_PARAMETER_PRESENCE("Mandatory Parameters are present in parameter set"),
    LEVEL_04_QUALIFIES_PARAMETER_COMPLETENESS("Parameters are availble and valid in context"),
    LEVEL_05_QUALIFIES_SOURCE_AND_DESTINATION("Mandatory source and destination are present in parameter set"),
    LEVEL_06_QUALIFIES_EXECUTION("Present source and destination in parameter set are availble in context");
    private String description;

    QualificationClassification(String description){
        this.description = description;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    
    public String getDefaultNonExecutionQualificationExplanation(){
        switch (this) {
        case LEVEL_00_DISQUALIFIED:
            return "Request is not recognized or not compatible";        
        case LEVEL_01_QUALIFIES_MODEL:
            return "The server command referred is not installed or is not available to current user";
        case LEVEL_02_QUALIFIES_COMMANDS:
            return "Mandatory parameters are missing";
        case LEVEL_03_QUALIFIES_PARAMETER_PRESENCE:
            return "Parameters are invalid or refers to resources that are not available";
        case LEVEL_04_QUALIFIES_PARAMETER_COMPLETENESS:
            return "Source or destination parameter is missing";
        case LEVEL_05_QUALIFIES_SOURCE_AND_DESTINATION:
            return "Source or destination parameter refers to resources that are not available";
        default:
            return "";
        }
    }
}
