package com.clcbio.client.thin.model.tree;

import com.clcbio.client.thin.model.CLCObjectReference;
import com.clcbio.client.thin.model.clcurl.ClcUrlParameter;
import com.clcbio.client.thin.model.importexport.ExportPluginReference;
import com.google.gwt.user.client.rpc.IsSerializable;

/**
 * @author jschultz A Tree gWTTreeItem with selected CLC PersistenceStructure
 *         fields This object represents a browsing of the Models without
 *         actually fetching the underlying objects.
 */
public class CLCTreeItem implements IsSerializable {
    private CLCObjectReference objectReference;
    private boolean recycled;
    private String title;
    private boolean isFolder;
    private boolean isUnknownClcFileObject;
    private CLCTreeItem[] children;
    private String description;
    private String iconPath;
    private int iconHeight;
    private int iconWidth;
    private String html;
    private boolean userHasAccess;
    private ExportPluginReference[] exportPluginReferences;
    private ClcUrlParameter clcUrlParameter;

    public ExportPluginReference[] getExportPluginReferences() {
        return exportPluginReferences;
    }

    public void setExportPluginReferences(ExportPluginReference[] exportPluginReferences) {
        this.exportPluginReferences = exportPluginReferences;
    }

    public String getHtml() {
        return html;
    }

    public void setHtml(String html) {
        this.html = html;
    }

    public String getIconPath() {
        return iconPath;
    }

    public void setIconPath(String iconPath) {
        this.iconPath = iconPath;
    }

    public int getIconHeight() {
        return iconHeight;
    }

    public void setIconHeight(int iconHeight) {
        this.iconHeight = iconHeight;
    }

    public int getIconWidth() {
        return iconWidth;
    }

    public void setIconWidth(int iconWidth) {
        this.iconWidth = iconWidth;
    }

    /**
     * @return the description
     */
    public String getDescription() {
        return description;
    }

    /**
     * @param description
     *            the description to set
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * @return the children
     */
    public CLCTreeItem[] getChildren() {
        return children;
    }

    /**
     * @param children
     *            the children to set
     */
    public void setChildren(CLCTreeItem[] children) {
        this.children = children;
    }

    public CLCTreeItem(String title) {
        this();
        setTitle(title);
    }

    public CLCTreeItem() {
        setTitle("");
        setFolder(false);
        setObjectReference(new CLCObjectReference());
    }

    /**
     * @return the title
     */
    public String getTitle() {
        return title;
    }

    /**
     * @param title
     *            the title to set
     */
    public void setTitle(String title) {
        this.title = title;
    }

    public CLCTreeItem(CLCTreeItem cLCTreeItem) {
        /*
         * Clone
         */
        setChildren(cLCTreeItem.children);
        this.setObjectReference(cLCTreeItem.getObjectReference());
        this.setFolder(cLCTreeItem.isFolder());
        this.setObjectId(cLCTreeItem.getObjectId());
        this.setTitle(cLCTreeItem.getTitle());
        this.setPersistenceModelId(cLCTreeItem.getPersistenceModelId());
        this.setDescription(cLCTreeItem.getDescription());
        this.setIconHeight(cLCTreeItem.getIconHeight());
        this.setIconPath(cLCTreeItem.getIconPath());
        this.setIconWidth(cLCTreeItem.getIconWidth());
        this.setExportPluginReferences(cLCTreeItem.getExportPluginReferences());
        this.setUserHasAccess(cLCTreeItem.isUserHasAccess());
        this.setHtml(cLCTreeItem.getHtml());
        this.setRecycled(cLCTreeItem.isRecycled());
        this.setUnknownClcFileObject(cLCTreeItem.isUnknownClcFileObject());
        this.setClcUrlParameter(cLCTreeItem.getClcUrlParameter());

    }

    public CLCTreeItem(String text, CLCTreeItem[] children) {
        this(text);
        setChildren(children);
        setFolder(true);

    }

    // public CLCTreeItem(String title, String objectId, boolean isFolder,
    // String persistenceModelId) {
    // setFolder(isFolder);
    // setObjectId(objectId);
    // setTitle(title);
    // setPersistenceModelId(persistenceModelId);
    // }
    /**
     * @return the objectId
     */
    public String getObjectId() {
        return objectReference.getClcObjectId();
    }

    /**
     * @param objectId
     *            the objectId to set
     */
    public void setObjectId(String objectId) {
        this.objectReference.setClcObjectId(objectId);
    }

    /**
     * @return the isFolder
     */
    public boolean isFolder() {
        return isFolder;
    }

    /**
     * @param isFolder
     *            the isFolder to set
     */
    public void setFolder(boolean isFolder) {
        this.isFolder = isFolder;
    }

    /**
     * @return the persistenceModelId
     */
    public String getPersistenceModelId() {
        return objectReference.getPersistenceModelId();
    }

    /**
     * @param persistenceModelId
     *            the persistenceModelId to set
     */
    public void setPersistenceModelId(String persistenceModelId) {
        this.objectReference.setPersistenceModelId(persistenceModelId);
    }

    /**
     * @return the userHasAccess
     */
    public boolean isUserHasAccess() {
        return userHasAccess;
    }

    /**
     * @param userHasAccess
     *            the userHasAccess to set
     */
    public void setUserHasAccess(boolean userHasAccess) {
        this.userHasAccess = userHasAccess;
    }

    /**
     * @return the recycled
     */
    public boolean isRecycled() {
        return recycled;
    }

    /**
     * @param recycled
     *            the recycled to set
     */
    public void setRecycled(boolean recycled) {
        this.recycled = recycled;
    }

    public CLCObjectReference getObjectReference() {
        return objectReference;
    }

    public void setObjectReference(CLCObjectReference objectReference) {
        this.objectReference = objectReference;
    }

    public void setObjectName(String name) {
        this.objectReference.setObjectName(name);
    }

    public String getObjectName() {
        return objectReference.getObjectName();
    }

    public boolean isUnknownClcFileObject() {
        return isUnknownClcFileObject;
    }

    public void setUnknownClcFileObject(boolean isUnknownClcFileObject) {
        this.isUnknownClcFileObject = isUnknownClcFileObject;
    }

    public void setClcUrlParameter(ClcUrlParameter clcUrlParameter) {
        this.clcUrlParameter = clcUrlParameter;
    }

    public ClcUrlParameter getClcUrlParameter() {
        return clcUrlParameter;
    }
    
    @Override
    public boolean equals(Object obj) {
    	if(obj instanceof CLCTreeItem) {
    		return ((CLCTreeItem) obj).getObjectReference().equals(this.getObjectReference());
    	}
    	return false;
    }

}
